0 BOS/EOS,*,*,*,*,*,*
1 その他,間投,*,*,*,*,*
2 フィラー,*,*,*,*,*,*
3 フィラー,*,*,*,*,*,あ
4 フィラー,*,*,*,*,*,あの
5 フィラー,*,*,*,*,*,あのー
6 フィラー,*,*,*,*,*,あー
7 フィラー,*,*,*,*,*,え
8 フィラー,*,*,*,*,*,えー
9 フィラー,*,*,*,*,*,えーと
10 フィラー,*,*,*,*,*,と
11 フィラー,*,*,*,*,*,ま
12 副詞,一般,*,*,*,*,*
13 副詞,一般,*,*,*,*,もう
14 副詞,一般,*,*,*,*,よく
15 副詞,一般,*,*,*,*,より
16 副詞,助詞類接続,*,*,*,*,*
17 副詞,助詞類接続,*,*,*,*,こう
18 副詞,助詞類接続,*,*,*,*,さ
19 副詞,助詞類接続,*,*,*,*,さらに
20 副詞,助詞類接続,*,*,*,*,すぐ
21 副詞,助詞類接続,*,*,*,*,そう
22 副詞,助詞類接続,*,*,*,*,どう
23 副詞,助詞類接続,*,*,*,*,どぉ
24 副詞,助詞類接続,*,*,*,*,なぜ
25 副詞,助詞類接続,*,*,*,*,なんでも
26 副詞,助詞類接続,*,*,*,*,まだ
27 副詞,助詞類接続,*,*,*,*,ホッ
28 副詞,助詞類接続,*,*,*,*,何でも
29 助動詞,*,*,*,下二・タ行,仮定形,つ
30 助動詞,*,*,*,下二・タ行,体言接続,つ
31 助動詞,*,*,*,下二・タ行,命令ｙｏ,つ
32 助動詞,*,*,*,下二・タ行,基本形,つ
33 助動詞,*,*,*,下二・タ行,未然形,つ
34 助動詞,*,*,*,下二・タ行,連用形,つ
35 助動詞,*,*,*,不変化型,基本形,う
36 助動詞,*,*,*,不変化型,基本形,じ
37 助動詞,*,*,*,不変化型,基本形,じゃん
38 助動詞,*,*,*,不変化型,基本形,じゃン
39 助動詞,*,*,*,不変化型,基本形,っ
40 助動詞,*,*,*,不変化型,基本形,ぬ
41 助動詞,*,*,*,不変化型,基本形,ひん
42 助動詞,*,*,*,不変化型,基本形,へん
43 助動詞,*,*,*,不変化型,基本形,まい
44 助動詞,*,*,*,不変化型,基本形,やん
45 助動詞,*,*,*,不変化型,基本形,ん
46 助動詞,*,*,*,不変化型,基本形,ー
47 助動詞,*,*,*,不変化型,基本形,～
48 助動詞,*,*,*,不変化形,基本形,ん
49 助動詞,*,*,*,五段・ラ行アル,仮定形,ある
50 助動詞,*,*,*,五段・ラ行アル,仮定縮約１,ある
51 助動詞,*,*,*,五段・ラ行アル,体言接続特殊,ある
52 助動詞,*,*,*,五段・ラ行アル,命令ｅ,ある
53 助動詞,*,*,*,五段・ラ行アル,基本形,ある
54 助動詞,*,*,*,五段・ラ行アル,未然ウ接続,ある
55 助動詞,*,*,*,五段・ラ行アル,未然形,ある
56 助動詞,*,*,*,五段・ラ行アル,連用タ接続,ある
57 助動詞,*,*,*,五段・ラ行アル,連用形,ある
58 助動詞,*,*,*,五段・ラ行特殊,仮定形,ござる
59 助動詞,*,*,*,五段・ラ行特殊,仮定縮約１,ござる
60 助動詞,*,*,*,五段・ラ行特殊,命令ｅ,ござる
61 助動詞,*,*,*,五段・ラ行特殊,命令ｉ,ござる
62 助動詞,*,*,*,五段・ラ行特殊,基本形,ござる
63 助動詞,*,*,*,五段・ラ行特殊,基本形,ゴザル
64 助動詞,*,*,*,五段・ラ行特殊,未然ウ接続,ござる
65 助動詞,*,*,*,五段・ラ行特殊,未然形,ござる
66 助動詞,*,*,*,五段・ラ行特殊,未然特殊,ござる
67 助動詞,*,*,*,五段・ラ行特殊,連用タ接続,ござる
68 助動詞,*,*,*,五段・ラ行特殊,連用形,ござる
69 助動詞,*,*,*,五段・ラ行特殊,連用形,ゴザル
70 助動詞,*,*,*,形容詞・イ段,ガル接続,らしい
71 助動詞,*,*,*,形容詞・イ段,ガル接続,無い
72 助動詞,*,*,*,形容詞・イ段,仮定形,らしい
73 助動詞,*,*,*,形容詞・イ段,仮定形,無い
74 助動詞,*,*,*,形容詞・イ段,仮定縮約１,らしい
75 助動詞,*,*,*,形容詞・イ段,仮定縮約１,無い
76 助動詞,*,*,*,形容詞・イ段,仮定縮約２,らしい
77 助動詞,*,*,*,形容詞・イ段,仮定縮約２,無い
78 助動詞,*,*,*,形容詞・イ段,体言接続,らしい
79 助動詞,*,*,*,形容詞・イ段,体言接続,無い
80 助動詞,*,*,*,形容詞・イ段,命令ｅ,らしい
81 助動詞,*,*,*,形容詞・イ段,命令ｅ,無い
82 助動詞,*,*,*,形容詞・イ段,基本形,らしい
83 助動詞,*,*,*,形容詞・イ段,基本形,無い
84 助動詞,*,*,*,形容詞・イ段,文語基本形,らしい
85 助動詞,*,*,*,形容詞・イ段,文語基本形,無い
86 助動詞,*,*,*,形容詞・イ段,未然ウ接続,らしい
87 助動詞,*,*,*,形容詞・イ段,未然ウ接続,無い
88 助動詞,*,*,*,形容詞・イ段,未然ヌ接続,らしい
89 助動詞,*,*,*,形容詞・イ段,未然ヌ接続,無い
90 助動詞,*,*,*,形容詞・イ段,連用ゴザイ接続,らしい
91 助動詞,*,*,*,形容詞・イ段,連用ゴザイ接続,無い
92 助動詞,*,*,*,形容詞・イ段,連用タ接続,らしい
93 助動詞,*,*,*,形容詞・イ段,連用タ接続,無い
94 助動詞,*,*,*,形容詞・イ段,連用テ接続,らしい
95 助動詞,*,*,*,形容詞・イ段,連用テ接続,無い
96 助動詞,*,*,*,文語・キ,体言接続,き
97 助動詞,*,*,*,文語・キ,命令ｅ,き
98 助動詞,*,*,*,文語・キ,基本形,き
99 助動詞,*,*,*,文語・ケリ,体言接続,けり
100 助動詞,*,*,*,文語・ケリ,基本形,けり
101 助動詞,*,*,*,文語・ゴトシ,体言接続,ごとし
102 助動詞,*,*,*,文語・ゴトシ,体言接続,如し
103 助動詞,*,*,*,文語・ゴトシ,基本形,ごとし
104 助動詞,*,*,*,文語・ゴトシ,基本形,如し
105 助動詞,*,*,*,文語・ゴトシ,連用形,ごとし
106 助動詞,*,*,*,文語・ゴトシ,連用形,如し
107 助動詞,*,*,*,文語・ナリ,仮定形,たり
108 助動詞,*,*,*,文語・ナリ,仮定形,なり
109 助動詞,*,*,*,文語・ナリ,体言接続,たり
110 助動詞,*,*,*,文語・ナリ,体言接続,なり
111 助動詞,*,*,*,文語・ナリ,体言接続,タリ
112 助動詞,*,*,*,文語・ナリ,命令ｅ,たり
113 助動詞,*,*,*,文語・ナリ,命令ｅ,なり
114 助動詞,*,*,*,文語・ナリ,基本形,たり
115 助動詞,*,*,*,文語・ナリ,基本形,なり
116 助動詞,*,*,*,文語・ナリ,未然形,たり
117 助動詞,*,*,*,文語・ナリ,未然形,なり
118 助動詞,*,*,*,文語・ベシ,仮定形,べし
119 助動詞,*,*,*,文語・ベシ,体言接続,べし
120 助動詞,*,*,*,文語・ベシ,基本形,べし
121 助動詞,*,*,*,文語・ベシ,基本形,ベシ
122 助動詞,*,*,*,文語・ベシ,未然形,べし
123 助動詞,*,*,*,文語・ベシ,連用形,べし
124 助動詞,*,*,*,文語・マジ,仮定形,まじ
125 助動詞,*,*,*,文語・マジ,体言接続,まじ
126 助動詞,*,*,*,文語・マジ,基本形,まじ
127 助動詞,*,*,*,文語・マジ,連用形,まじ
128 助動詞,*,*,*,文語・リ,体言接続,り
129 助動詞,*,*,*,文語・リ,基本形,り
130 助動詞,*,*,*,文語・ル,仮定形,る
131 助動詞,*,*,*,文語・ル,体言接続,る
132 助動詞,*,*,*,文語・ル,命令ｅ,る
133 助動詞,*,*,*,文語・ル,命令ｙｏ,る
134 助動詞,*,*,*,文語・ル,基本形,る
135 助動詞,*,*,*,文語・ル,未然形,る
136 助動詞,*,*,*,文語・ル,連用形,る
137 助動詞,*,*,*,特殊・ジャ,基本形,じゃ
138 助動詞,*,*,*,特殊・ジャ,未然形,じゃ
139 助動詞,*,*,*,特殊・ジャ,連用形,じゃ
140 助動詞,*,*,*,特殊・タ,仮定形,た
141 助動詞,*,*,*,特殊・タ,仮定形,だ
142 助動詞,*,*,*,特殊・タ,基本形,た
143 助動詞,*,*,*,特殊・タ,基本形,だ
144 助動詞,*,*,*,特殊・タ,未然形,た
145 助動詞,*,*,*,特殊・タ,未然形,だ
146 助動詞,*,*,*,特殊・タイ,ガル接続,たい
147 助動詞,*,*,*,特殊・タイ,仮定形,たい
148 助動詞,*,*,*,特殊・タイ,仮定縮約１,たい
149 助動詞,*,*,*,特殊・タイ,仮定縮約２,たい
150 助動詞,*,*,*,特殊・タイ,体言接続,たい
151 助動詞,*,*,*,特殊・タイ,基本形,たぁい
152 助動詞,*,*,*,特殊・タイ,基本形,たい
153 助動詞,*,*,*,特殊・タイ,基本形,たーい
154 助動詞,*,*,*,特殊・タイ,基本形,た～い
155 助動詞,*,*,*,特殊・タイ,文語基本形,たい
156 助動詞,*,*,*,特殊・タイ,未然ウ接続,たい
157 助動詞,*,*,*,特殊・タイ,未然ヌ接続,たい
158 助動詞,*,*,*,特殊・タイ,連用ゴザイ接続,たい
159 助動詞,*,*,*,特殊・タイ,連用タ接続,たい
160 助動詞,*,*,*,特殊・タイ,連用テ接続,たい
161 助動詞,*,*,*,特殊・タイ,音便基本形,たい
162 助動詞,*,*,*,特殊・ダ,仮定形,だ
163 助動詞,*,*,*,特殊・ダ,体言接続,だ
164 助動詞,*,*,*,特殊・ダ,命令ｅ,だ
165 助動詞,*,*,*,特殊・ダ,基本形,だ
166 助動詞,*,*,*,特殊・ダ,未然形,だ
167 助動詞,*,*,*,特殊・ダ,連用タ接続,だ
168 助動詞,*,*,*,特殊・ダ,連用形,だ
169 助動詞,*,*,*,特殊・デス,基本形,っす
170 助動詞,*,*,*,特殊・デス,基本形,でぇす
171 助動詞,*,*,*,特殊・デス,基本形,でしょう
172 助動詞,*,*,*,特殊・デス,基本形,です
173 助動詞,*,*,*,特殊・デス,基本形,でっす
174 助動詞,*,*,*,特殊・デス,基本形,でーす
175 助動詞,*,*,*,特殊・デス,基本形,で～す
176 助動詞,*,*,*,特殊・デス,基本形,どす
177 助動詞,*,*,*,特殊・デス,基本形,ッス
178 助動詞,*,*,*,特殊・デス,基本形,デス
179 助動詞,*,*,*,特殊・デス,基本形,ドス
180 助動詞,*,*,*,特殊・デス,未然形,っす
181 助動詞,*,*,*,特殊・デス,未然形,でぇす
182 助動詞,*,*,*,特殊・デス,未然形,でしょう
183 助動詞,*,*,*,特殊・デス,未然形,です
184 助動詞,*,*,*,特殊・デス,未然形,でっす
185 助動詞,*,*,*,特殊・デス,未然形,でーす
186 助動詞,*,*,*,特殊・デス,未然形,で～す
187 助動詞,*,*,*,特殊・デス,未然形,どす
188 助動詞,*,*,*,特殊・デス,未然形,ッス
189 助動詞,*,*,*,特殊・デス,連用形,っす
190 助動詞,*,*,*,特殊・デス,連用形,でぇす
191 助動詞,*,*,*,特殊・デス,連用形,でしょう
192 助動詞,*,*,*,特殊・デス,連用形,です
193 助動詞,*,*,*,特殊・デス,連用形,でっす
194 助動詞,*,*,*,特殊・デス,連用形,でーす
195 助動詞,*,*,*,特殊・デス,連用形,で～す
196 助動詞,*,*,*,特殊・デス,連用形,どす
197 助動詞,*,*,*,特殊・ナイ,ガル接続,ない
198 助動詞,*,*,*,特殊・ナイ,仮定形,ない
199 助動詞,*,*,*,特殊・ナイ,仮定縮約１,ない
200 助動詞,*,*,*,特殊・ナイ,仮定縮約２,ない
201 助動詞,*,*,*,特殊・ナイ,体言接続,ない
202 助動詞,*,*,*,特殊・ナイ,命令ｅ,ない
203 助動詞,*,*,*,特殊・ナイ,基本形,なぁい
204 助動詞,*,*,*,特殊・ナイ,基本形,ない
205 助動詞,*,*,*,特殊・ナイ,基本形,なーい
206 助動詞,*,*,*,特殊・ナイ,基本形,な～い
207 助動詞,*,*,*,特殊・ナイ,文語基本形,ない
208 助動詞,*,*,*,特殊・ナイ,未然ウ接続,ない
209 助動詞,*,*,*,特殊・ナイ,未然ヌ接続,ない
210 助動詞,*,*,*,特殊・ナイ,連用ゴザイ接続,ない
211 助動詞,*,*,*,特殊・ナイ,連用タ接続,ない
212 助動詞,*,*,*,特殊・ナイ,連用テ接続,ない
213 助動詞,*,*,*,特殊・ナイ,連用デ接続,ない
214 助動詞,*,*,*,特殊・ナイ,音便基本形,ない
215 助動詞,*,*,*,特殊・ヌ,仮定形,ぬ
216 助動詞,*,*,*,特殊・ヌ,体言接続,ぬ
217 助動詞,*,*,*,特殊・ヌ,基本形,ぬ
218 助動詞,*,*,*,特殊・ヌ,文語基本形,ぬ
219 助動詞,*,*,*,特殊・ヌ,連用ニ接続,ぬ
220 助動詞,*,*,*,特殊・ヌ,連用形,ぬ
221 助動詞,*,*,*,特殊・マス,仮定形,まぁす
222 助動詞,*,*,*,特殊・マス,仮定形,ます
223 助動詞,*,*,*,特殊・マス,仮定形,まっす
224 助動詞,*,*,*,特殊・マス,仮定形,まーす
225 助動詞,*,*,*,特殊・マス,仮定形,ま～す
226 助動詞,*,*,*,特殊・マス,仮定形,やす
227 助動詞,*,*,*,特殊・マス,命令ｅ,まぁす
228 助動詞,*,*,*,特殊・マス,命令ｅ,ます
229 助動詞,*,*,*,特殊・マス,命令ｅ,まっす
230 助動詞,*,*,*,特殊・マス,命令ｅ,まーす
231 助動詞,*,*,*,特殊・マス,命令ｅ,ま～す
232 助動詞,*,*,*,特殊・マス,命令ｅ,やす
233 助動詞,*,*,*,特殊・マス,命令ｉ,まぁす
234 助動詞,*,*,*,特殊・マス,命令ｉ,ます
235 助動詞,*,*,*,特殊・マス,命令ｉ,まっす
236 助動詞,*,*,*,特殊・マス,命令ｉ,まーす
237 助動詞,*,*,*,特殊・マス,命令ｉ,ま～す
238 助動詞,*,*,*,特殊・マス,命令ｉ,やす
239 助動詞,*,*,*,特殊・マス,基本形,まぁす
240 助動詞,*,*,*,特殊・マス,基本形,ます
241 助動詞,*,*,*,特殊・マス,基本形,まっす
242 助動詞,*,*,*,特殊・マス,基本形,まーす
243 助動詞,*,*,*,特殊・マス,基本形,ま～す
244 助動詞,*,*,*,特殊・マス,基本形,やす
245 助動詞,*,*,*,特殊・マス,未然ウ接続,まぁす
246 助動詞,*,*,*,特殊・マス,未然ウ接続,ます
247 助動詞,*,*,*,特殊・マス,未然ウ接続,まっす
248 助動詞,*,*,*,特殊・マス,未然ウ接続,まーす
249 助動詞,*,*,*,特殊・マス,未然ウ接続,ま～す
250 助動詞,*,*,*,特殊・マス,未然ウ接続,やす
251 助動詞,*,*,*,特殊・マス,未然形,まぁす
252 助動詞,*,*,*,特殊・マス,未然形,ます
253 助動詞,*,*,*,特殊・マス,未然形,ますー
254 助動詞,*,*,*,特殊・マス,未然形,ます～
255 助動詞,*,*,*,特殊・マス,未然形,まっす
256 助動詞,*,*,*,特殊・マス,未然形,まーす
257 助動詞,*,*,*,特殊・マス,未然形,ま～す
258 助動詞,*,*,*,特殊・マス,未然形,やす
259 助動詞,*,*,*,特殊・マス,連用形,まぁす
260 助動詞,*,*,*,特殊・マス,連用形,ます
261 助動詞,*,*,*,特殊・マス,連用形,まっす
262 助動詞,*,*,*,特殊・マス,連用形,まーす
263 助動詞,*,*,*,特殊・マス,連用形,ま～す
264 助動詞,*,*,*,特殊・マス,連用形,やす
265 助動詞,*,*,*,特殊・ヤ,基本形,や
266 助動詞,*,*,*,特殊・ヤ,未然形,や
267 助動詞,*,*,*,特殊・ヤ,連用形,や
268 助詞,並立助詞,*,*,*,*,たり
269 助詞,並立助詞,*,*,*,*,だの
270 助詞,並立助詞,*,*,*,*,だり
271 助詞,並立助詞,*,*,*,*,と
272 助詞,並立助詞,*,*,*,*,とか
273 助詞,並立助詞,*,*,*,*,なり
274 助詞,並立助詞,*,*,*,*,や
275 助詞,並立助詞,*,*,*,*,やら
276 助詞,並立助詞,*,*,*,*,トカ
277 助詞,係助詞,*,*,*,*,こそ
278 助詞,係助詞,*,*,*,*,さえ
279 助詞,係助詞,*,*,*,*,しか
280 助詞,係助詞,*,*,*,*,すら
281 助詞,係助詞,*,*,*,*,ぞ
282 助詞,係助詞,*,*,*,*,っきゃ
283 助詞,係助詞,*,*,*,*,は
284 助詞,係助詞,*,*,*,*,も
285 助詞,係助詞,*,*,*,*,や
286 助詞,係助詞,*,*,*,*,やいかに
287 助詞,係助詞,*,*,*,*,や如何に
288 助詞,副助詞,*,*,*,*,かも
289 助詞,副助詞,*,*,*,*,くらい
290 助詞,副助詞,*,*,*,*,ぐらい
291 助詞,副助詞,*,*,*,*,しも
292 助詞,副助詞,*,*,*,*,じゃ
293 助詞,副助詞,*,*,*,*,じゃあ
294 助詞,副助詞,*,*,*,*,じゃァ
295 助詞,副助詞,*,*,*,*,ずつ
296 助詞,副助詞,*,*,*,*,だけ
297 助詞,副助詞,*,*,*,*,だって
298 助詞,副助詞,*,*,*,*,だに
299 助詞,副助詞,*,*,*,*,でも
300 助詞,副助詞,*,*,*,*,とも
301 助詞,副助詞,*,*,*,*,なぞ
302 助詞,副助詞,*,*,*,*,など
303 助詞,副助詞,*,*,*,*,なり
304 助詞,副助詞,*,*,*,*,なんか
305 助詞,副助詞,*,*,*,*,なんざ
306 助詞,副助詞,*,*,*,*,なんぞ
307 助詞,副助詞,*,*,*,*,なんて
308 助詞,副助詞,*,*,*,*,のみ
309 助詞,副助詞,*,*,*,*,ばかし
310 助詞,副助詞,*,*,*,*,ばかり
311 助詞,副助詞,*,*,*,*,ばっか
312 助詞,副助詞,*,*,*,*,ばっかり
313 助詞,副助詞,*,*,*,*,ほど
314 助詞,副助詞,*,*,*,*,まで
315 助詞,副助詞,*,*,*,*,やら
316 助詞,副助詞,*,*,*,*,ダケ
317 助詞,副助詞,*,*,*,*,ナド
318 助詞,副助詞,*,*,*,*,ナンゾ
319 助詞,副助詞,*,*,*,*,ナンテ
320 助詞,副助詞,*,*,*,*,バカリ
321 助詞,副助詞,*,*,*,*,バッカリ
322 助詞,副助詞,*,*,*,*,マデ
323 助詞,副助詞,*,*,*,*,程
324 助詞,副助詞,*,*,*,*,迄
325 助詞,副助詞／並立助詞／終助詞,*,*,*,*,か
326 助詞,副詞化,*,*,*,*,と
327 助詞,副詞化,*,*,*,*,に
328 助詞,助詞連続,*,*,*,*,はね
329 助詞,接続助詞,*,*,*,*,および
330 助詞,接続助詞,*,*,*,*,から
331 助詞,接続助詞,*,*,*,*,からには
332 助詞,接続助詞,*,*,*,*,が
333 助詞,接続助詞,*,*,*,*,がてら
334 助詞,接続助詞,*,*,*,*,けど
335 助詞,接続助詞,*,*,*,*,けども
336 助詞,接続助詞,*,*,*,*,けれど
337 助詞,接続助詞,*,*,*,*,けれども
338 助詞,接続助詞,*,*,*,*,さかい
339 助詞,接続助詞,*,*,*,*,し
340 助詞,接続助詞,*,*,*,*,じゃ
341 助詞,接続助詞,*,*,*,*,じゃあ
342 助詞,接続助詞,*,*,*,*,じゃー
343 助詞,接続助詞,*,*,*,*,たって
344 助詞,接続助詞,*,*,*,*,ちゃ
345 助詞,接続助詞,*,*,*,*,ちゃあ
346 助詞,接続助詞,*,*,*,*,ちゃー
347 助詞,接続助詞,*,*,*,*,つつ
348 助詞,接続助詞,*,*,*,*,て
349 助詞,接続助詞,*,*,*,*,で
350 助詞,接続助詞,*,*,*,*,と
351 助詞,接続助詞,*,*,*,*,とも
352 助詞,接続助詞,*,*,*,*,ど
353 助詞,接続助詞,*,*,*,*,どころか
354 助詞,接続助詞,*,*,*,*,ども
355 助詞,接続助詞,*,*,*,*,ながら
356 助詞,接続助詞,*,*,*,*,なり
357 助詞,接続助詞,*,*,*,*,につけ
358 助詞,接続助詞,*,*,*,*,にも
359 助詞,接続助詞,*,*,*,*,ので
360 助詞,接続助詞,*,*,*,*,のに
361 助詞,接続助詞,*,*,*,*,ば
362 助詞,接続助詞,*,*,*,*,ものの
363 助詞,接続助詞,*,*,*,*,や
364 助詞,接続助詞,*,*,*,*,やいなや
365 助詞,接続助詞,*,*,*,*,んで
366 助詞,接続助詞,*,*,*,*,ケド
367 助詞,接続助詞,一般,*,*,*,に
368 助詞,格助詞,一般,*,*,*,から
369 助詞,格助詞,一般,*,*,*,が
370 助詞,格助詞,一般,*,*,*,で
371 助詞,格助詞,一般,*,*,*,と
372 助詞,格助詞,一般,*,*,*,に
373 助詞,格助詞,一般,*,*,*,にて
374 助詞,格助詞,一般,*,*,*,の
375 助詞,格助詞,一般,*,*,*,へ
376 助詞,格助詞,一般,*,*,*,もの
377 助詞,格助詞,一般,*,*,*,よか
378 助詞,格助詞,一般,*,*,*,より
379 助詞,格助詞,一般,*,*,*,を
380 助詞,格助詞,一般,*,*,*,ん
381 助詞,格助詞,一般,*,*,*,デ
382 助詞,格助詞,一般,*,*,*,ノ
383 助詞,格助詞,一般,*,*,*,ヘ
384 助詞,格助詞,一般,*,*,*,ヲ
385 助詞,格助詞,一般,*,*,*,之
386 助詞,格助詞,引用,*,*,*,っと
387 助詞,格助詞,引用,*,*,*,と
388 助詞,格助詞,引用,*,*,*,ット
389 助詞,格助詞,意志,*,*,*,と
390 助詞,格助詞,連語,*,*,*,じゃ
391 助詞,格助詞,連語,*,*,*,って
392 助詞,格助詞,連語,*,*,*,っていう
393 助詞,格助詞,連語,*,*,*,ってな
394 助詞,格助詞,連語,*,*,*,ていう
395 助詞,格助詞,連語,*,*,*,という
396 助詞,格助詞,連語,*,*,*,とかいう
397 助詞,格助詞,連語,*,*,*,について
398 助詞,格助詞,連語,*,*,*,にとって
399 助詞,特殊,*,*,*,*,かな
400 助詞,特殊,*,*,*,*,けむ
401 助詞,特殊,*,*,*,*,に
402 助詞,特殊,*,*,*,*,にゃ
403 助詞,特殊,*,*,*,*,ん
404 助詞,特殊,*,*,*,*,ニャ
405 助詞,終助詞,*,*,*,*,かぁ
406 助詞,終助詞,*,*,*,*,かい
407 助詞,終助詞,*,*,*,*,かしら
408 助詞,終助詞,*,*,*,*,かな
409 助詞,終助詞,*,*,*,*,け
410 助詞,終助詞,*,*,*,*,さ
411 助詞,終助詞,*,*,*,*,ぜ
412 助詞,終助詞,*,*,*,*,ぞ
413 助詞,終助詞,*,*,*,*,だって
414 助詞,終助詞,*,*,*,*,っけ
415 助詞,終助詞,*,*,*,*,てん
416 助詞,終助詞,*,*,*,*,で
417 助詞,終助詞,*,*,*,*,な
418 助詞,終助詞,*,*,*,*,ね
419 助詞,終助詞,*,*,*,*,の
420 助詞,終助詞,*,*,*,*,のう
421 助詞,終助詞,*,*,*,*,べ
422 助詞,終助詞,*,*,*,*,もん
423 助詞,終助詞,*,*,*,*,や
424 助詞,終助詞,*,*,*,*,やら
425 助詞,終助詞,*,*,*,*,よ
426 助詞,終助詞,*,*,*,*,わ
427 助詞,終助詞,*,*,*,*,わい
428 助詞,終助詞,*,*,*,*,ん
429 助詞,連体化,*,*,*,*,の
430 動詞,接尾,*,*,一段,仮定形,させる
431 動詞,接尾,*,*,一段,仮定形,しめる
432 動詞,接尾,*,*,一段,仮定形,せる
433 動詞,接尾,*,*,一段,仮定形,られる
434 動詞,接尾,*,*,一段,仮定形,れる
435 動詞,接尾,*,*,一段,仮定形,付ける
436 動詞,接尾,*,*,一段,仮定縮約１,させる
437 動詞,接尾,*,*,一段,仮定縮約１,しめる
438 動詞,接尾,*,*,一段,仮定縮約１,せる
439 動詞,接尾,*,*,一段,仮定縮約１,られる
440 動詞,接尾,*,*,一段,仮定縮約１,れる
441 動詞,接尾,*,*,一段,仮定縮約１,付ける
442 動詞,接尾,*,*,一段,体言接続特殊,させる
443 動詞,接尾,*,*,一段,体言接続特殊,しめる
444 動詞,接尾,*,*,一段,体言接続特殊,せる
445 動詞,接尾,*,*,一段,体言接続特殊,られる
446 動詞,接尾,*,*,一段,体言接続特殊,れる
447 動詞,接尾,*,*,一段,体言接続特殊,付ける
448 動詞,接尾,*,*,一段,命令ｒｏ,させる
449 動詞,接尾,*,*,一段,命令ｒｏ,しめる
450 動詞,接尾,*,*,一段,命令ｒｏ,せる
451 動詞,接尾,*,*,一段,命令ｒｏ,られる
452 動詞,接尾,*,*,一段,命令ｒｏ,れる
453 動詞,接尾,*,*,一段,命令ｒｏ,付ける
454 動詞,接尾,*,*,一段,命令ｙｏ,させる
455 動詞,接尾,*,*,一段,命令ｙｏ,しめる
456 動詞,接尾,*,*,一段,命令ｙｏ,せる
457 動詞,接尾,*,*,一段,命令ｙｏ,られる
458 動詞,接尾,*,*,一段,命令ｙｏ,れる
459 動詞,接尾,*,*,一段,命令ｙｏ,付ける
460 動詞,接尾,*,*,一段,基本形,させる
461 動詞,接尾,*,*,一段,基本形,しめる
462 動詞,接尾,*,*,一段,基本形,せる
463 動詞,接尾,*,*,一段,基本形,られる
464 動詞,接尾,*,*,一段,基本形,れる
465 動詞,接尾,*,*,一段,基本形,付ける
466 動詞,接尾,*,*,一段,未然ウ接続,させる
467 動詞,接尾,*,*,一段,未然ウ接続,しめる
468 動詞,接尾,*,*,一段,未然ウ接続,せる
469 動詞,接尾,*,*,一段,未然ウ接続,られる
470 動詞,接尾,*,*,一段,未然ウ接続,れる
471 動詞,接尾,*,*,一段,未然ウ接続,付ける
472 動詞,接尾,*,*,一段,未然形,させる
473 動詞,接尾,*,*,一段,未然形,しめる
474 動詞,接尾,*,*,一段,未然形,せる
475 動詞,接尾,*,*,一段,未然形,られる
476 動詞,接尾,*,*,一段,未然形,れる
477 動詞,接尾,*,*,一段,未然形,付ける
478 動詞,接尾,*,*,一段,連用形,させる
479 動詞,接尾,*,*,一段,連用形,しめる
480 動詞,接尾,*,*,一段,連用形,せる
481 動詞,接尾,*,*,一段,連用形,られる
482 動詞,接尾,*,*,一段,連用形,れる
483 動詞,接尾,*,*,一段,連用形,付ける
484 動詞,接尾,*,*,五段・サ行,仮定形,さす
485 動詞,接尾,*,*,五段・サ行,仮定形,す
486 動詞,接尾,*,*,五段・サ行,仮定形,剳す
487 動詞,接尾,*,*,五段・サ行,仮定形,扠す
488 動詞,接尾,*,*,五段・サ行,仮定形,扨す
489 動詞,接尾,*,*,五段・サ行,仮定形,捺す
490 動詞,接尾,*,*,五段・サ行,仮定形,箚す
491 動詞,接尾,*,*,五段・サ行,仮定形,點す
492 動詞,接尾,*,*,五段・サ行,仮定縮約１,さす
493 動詞,接尾,*,*,五段・サ行,仮定縮約１,す
494 動詞,接尾,*,*,五段・サ行,仮定縮約１,剳す
495 動詞,接尾,*,*,五段・サ行,仮定縮約１,扠す
496 動詞,接尾,*,*,五段・サ行,仮定縮約１,扨す
497 動詞,接尾,*,*,五段・サ行,仮定縮約１,捺す
498 動詞,接尾,*,*,五段・サ行,仮定縮約１,箚す
499 動詞,接尾,*,*,五段・サ行,仮定縮約１,點す
500 動詞,接尾,*,*,五段・サ行,命令ｅ,さす
501 動詞,接尾,*,*,五段・サ行,命令ｅ,す
502 動詞,接尾,*,*,五段・サ行,命令ｅ,剳す
503 動詞,接尾,*,*,五段・サ行,命令ｅ,扠す
504 動詞,接尾,*,*,五段・サ行,命令ｅ,扨す
505 動詞,接尾,*,*,五段・サ行,命令ｅ,捺す
506 動詞,接尾,*,*,五段・サ行,命令ｅ,箚す
507 動詞,接尾,*,*,五段・サ行,命令ｅ,點す
508 動詞,接尾,*,*,五段・サ行,基本形,さす
509 動詞,接尾,*,*,五段・サ行,基本形,す
510 動詞,接尾,*,*,五段・サ行,基本形,剳す
511 動詞,接尾,*,*,五段・サ行,基本形,扠す
512 動詞,接尾,*,*,五段・サ行,基本形,扨す
513 動詞,接尾,*,*,五段・サ行,基本形,捺す
514 動詞,接尾,*,*,五段・サ行,基本形,箚す
515 動詞,接尾,*,*,五段・サ行,基本形,點す
516 動詞,接尾,*,*,五段・サ行,未然ウ接続,さす
517 動詞,接尾,*,*,五段・サ行,未然ウ接続,す
518 動詞,接尾,*,*,五段・サ行,未然ウ接続,剳す
519 動詞,接尾,*,*,五段・サ行,未然ウ接続,扠す
520 動詞,接尾,*,*,五段・サ行,未然ウ接続,扨す
521 動詞,接尾,*,*,五段・サ行,未然ウ接続,捺す
522 動詞,接尾,*,*,五段・サ行,未然ウ接続,箚す
523 動詞,接尾,*,*,五段・サ行,未然ウ接続,點す
524 動詞,接尾,*,*,五段・サ行,未然形,さす
525 動詞,接尾,*,*,五段・サ行,未然形,す
526 動詞,接尾,*,*,五段・サ行,未然形,剳す
527 動詞,接尾,*,*,五段・サ行,未然形,扠す
528 動詞,接尾,*,*,五段・サ行,未然形,扨す
529 動詞,接尾,*,*,五段・サ行,未然形,捺す
530 動詞,接尾,*,*,五段・サ行,未然形,箚す
531 動詞,接尾,*,*,五段・サ行,未然形,點す
532 動詞,接尾,*,*,五段・サ行,連用形,さす
533 動詞,接尾,*,*,五段・サ行,連用形,す
534 動詞,接尾,*,*,五段・サ行,連用形,剳す
535 動詞,接尾,*,*,五段・サ行,連用形,扠す
536 動詞,接尾,*,*,五段・サ行,連用形,扨す
537 動詞,接尾,*,*,五段・サ行,連用形,捺す
538 動詞,接尾,*,*,五段・サ行,連用形,箚す
539 動詞,接尾,*,*,五段・サ行,連用形,點す
540 動詞,接尾,*,*,五段・ラ行,仮定形,がかる
541 動詞,接尾,*,*,五段・ラ行,仮定形,がる
542 動詞,接尾,*,*,五段・ラ行,仮定形,掛かる
543 動詞,接尾,*,*,五段・ラ行,仮定縮約１,がかる
544 動詞,接尾,*,*,五段・ラ行,仮定縮約１,がる
545 動詞,接尾,*,*,五段・ラ行,仮定縮約１,掛かる
546 動詞,接尾,*,*,五段・ラ行,体言接続特殊,がかる
547 動詞,接尾,*,*,五段・ラ行,体言接続特殊,がる
548 動詞,接尾,*,*,五段・ラ行,体言接続特殊,掛かる
549 動詞,接尾,*,*,五段・ラ行,体言接続特殊２,がかる
550 動詞,接尾,*,*,五段・ラ行,体言接続特殊２,がる
551 動詞,接尾,*,*,五段・ラ行,命令ｅ,がかる
552 動詞,接尾,*,*,五段・ラ行,命令ｅ,がる
553 動詞,接尾,*,*,五段・ラ行,命令ｅ,掛かる
554 動詞,接尾,*,*,五段・ラ行,基本形,がかる
555 動詞,接尾,*,*,五段・ラ行,基本形,がる
556 動詞,接尾,*,*,五段・ラ行,基本形,掛かる
557 動詞,接尾,*,*,五段・ラ行,未然ウ接続,がかる
558 動詞,接尾,*,*,五段・ラ行,未然ウ接続,がる
559 動詞,接尾,*,*,五段・ラ行,未然ウ接続,掛かる
560 動詞,接尾,*,*,五段・ラ行,未然形,がかる
561 動詞,接尾,*,*,五段・ラ行,未然形,がる
562 動詞,接尾,*,*,五段・ラ行,未然形,掛かる
563 動詞,接尾,*,*,五段・ラ行,未然特殊,がかる
564 動詞,接尾,*,*,五段・ラ行,未然特殊,がる
565 動詞,接尾,*,*,五段・ラ行,未然特殊,掛かる
566 動詞,接尾,*,*,五段・ラ行,連用タ接続,がかる
567 動詞,接尾,*,*,五段・ラ行,連用タ接続,がる
568 動詞,接尾,*,*,五段・ラ行,連用タ接続,掛かる
569 動詞,接尾,*,*,五段・ラ行,連用形,がかる
570 動詞,接尾,*,*,五段・ラ行,連用形,がる
571 動詞,接尾,*,*,五段・ラ行,連用形,掛かる
572 動詞,接尾,*,*,五段・ラ行,連用形,狩り
573 動詞,自立,*,*,*,体言接続特殊２,*
574 動詞,自立,*,*,*,文語基本形,*
575 動詞,自立,*,*,カ変・クル,仮定形,*
576 動詞,自立,*,*,カ変・クル,仮定形,来る
577 動詞,自立,*,*,カ変・クル,仮定縮約１,*
578 動詞,自立,*,*,カ変・クル,仮定縮約１,来る
579 動詞,自立,*,*,カ変・クル,体言接続特殊,*
580 動詞,自立,*,*,カ変・クル,体言接続特殊,来る
581 動詞,自立,*,*,カ変・クル,体言接続特殊２,来る
582 動詞,自立,*,*,カ変・クル,命令ｉ,*
583 動詞,自立,*,*,カ変・クル,命令ｉ,来る
584 動詞,自立,*,*,カ変・クル,命令ｙｏ,*
585 動詞,自立,*,*,カ変・クル,命令ｙｏ,来る
586 動詞,自立,*,*,カ変・クル,基本形,*
587 動詞,自立,*,*,カ変・クル,基本形,来る
588 動詞,自立,*,*,カ変・クル,未然ウ接続,*
589 動詞,自立,*,*,カ変・クル,未然ウ接続,来る
590 動詞,自立,*,*,カ変・クル,未然形,*
591 動詞,自立,*,*,カ変・クル,未然形,来る
592 動詞,自立,*,*,カ変・クル,連用形,*
593 動詞,自立,*,*,カ変・クル,連用形,来る
594 動詞,自立,*,*,カ変・来ル,仮定形,*
595 動詞,自立,*,*,カ変・来ル,仮定形,来る
596 動詞,自立,*,*,カ変・来ル,仮定縮約１,*
597 動詞,自立,*,*,カ変・来ル,仮定縮約１,来る
598 動詞,自立,*,*,カ変・来ル,体言接続特殊,*
599 動詞,自立,*,*,カ変・来ル,体言接続特殊,来る
600 動詞,自立,*,*,カ変・来ル,体言接続特殊２,来る
601 動詞,自立,*,*,カ変・来ル,命令ｉ,*
602 動詞,自立,*,*,カ変・来ル,命令ｉ,来る
603 動詞,自立,*,*,カ変・来ル,命令ｙｏ,*
604 動詞,自立,*,*,カ変・来ル,命令ｙｏ,来る
605 動詞,自立,*,*,カ変・来ル,基本形,*
606 動詞,自立,*,*,カ変・来ル,基本形,来る
607 動詞,自立,*,*,カ変・来ル,未然ウ接続,*
608 動詞,自立,*,*,カ変・来ル,未然ウ接続,来る
609 動詞,自立,*,*,カ変・来ル,未然形,*
610 動詞,自立,*,*,カ変・来ル,未然形,来る
611 動詞,自立,*,*,カ変・来ル,連用形,*
612 動詞,自立,*,*,カ変・来ル,連用形,来る
613 動詞,自立,*,*,サ変,仮定形,*
614 動詞,自立,*,*,サ変,仮定縮約１,*
615 動詞,自立,*,*,サ変,命令ｒｏ,*
616 動詞,自立,*,*,サ変,命令ｙｏ,*
617 動詞,自立,*,*,サ変,基本形,*
618 動詞,自立,*,*,サ変,文語基本形,*
619 動詞,自立,*,*,サ変,未然ウ接続,*
620 動詞,自立,*,*,サ変,未然レル接続,*
621 動詞,自立,*,*,サ変,未然形,*
622 動詞,自立,*,*,サ変,連用形,*
623 動詞,自立,*,*,サ変・スル,仮定形,*
624 動詞,自立,*,*,サ変・スル,仮定縮約１,*
625 動詞,自立,*,*,サ変・スル,体言接続特殊,*
626 動詞,自立,*,*,サ変・スル,命令ｉ,*
627 動詞,自立,*,*,サ変・スル,命令ｒｏ,*
628 動詞,自立,*,*,サ変・スル,命令ｙｏ,*
629 動詞,自立,*,*,サ変・スル,基本形,*
630 動詞,自立,*,*,サ変・スル,未然ウ接続,*
631 動詞,自立,*,*,サ変・スル,未然ヌ接続,*
632 動詞,自立,*,*,サ変・スル,未然レル接続,*
633 動詞,自立,*,*,サ変・スル,未然形,*
634 動詞,自立,*,*,サ変・スル,連用形,*
635 動詞,自立,*,*,ラ変,仮定形,*
636 動詞,自立,*,*,ラ変,体言接続,*
637 動詞,自立,*,*,ラ変,命令ｅ,*
638 動詞,自立,*,*,ラ変,基本形,*
639 動詞,自立,*,*,ラ変,未然形,*
640 動詞,自立,*,*,ラ変,連用形,*
641 動詞,自立,*,*,一段,仮定形,*
642 動詞,自立,*,*,一段,仮定形,いる
643 動詞,自立,*,*,一段,仮定形,おける
644 動詞,自立,*,*,一段,仮定形,できる
645 動詞,自立,*,*,一段,仮定形,出る
646 動詞,自立,*,*,一段,仮定形,出来る
647 動詞,自立,*,*,一段,仮定形,着る
648 動詞,自立,*,*,一段,仮定縮約１,*
649 動詞,自立,*,*,一段,仮定縮約１,いる
650 動詞,自立,*,*,一段,仮定縮約１,おける
651 動詞,自立,*,*,一段,仮定縮約１,できる
652 動詞,自立,*,*,一段,仮定縮約１,出る
653 動詞,自立,*,*,一段,仮定縮約１,出来る
654 動詞,自立,*,*,一段,仮定縮約１,着る
655 動詞,自立,*,*,一段,体言接続特殊,*
656 動詞,自立,*,*,一段,体言接続特殊,いる
657 動詞,自立,*,*,一段,体言接続特殊,おける
658 動詞,自立,*,*,一段,体言接続特殊,できる
659 動詞,自立,*,*,一段,体言接続特殊,出る
660 動詞,自立,*,*,一段,体言接続特殊,出来る
661 動詞,自立,*,*,一段,体言接続特殊,着る
662 動詞,自立,*,*,一段,命令ｒｏ,*
663 動詞,自立,*,*,一段,命令ｒｏ,いる
664 動詞,自立,*,*,一段,命令ｒｏ,おける
665 動詞,自立,*,*,一段,命令ｒｏ,できる
666 動詞,自立,*,*,一段,命令ｒｏ,出る
667 動詞,自立,*,*,一段,命令ｒｏ,出来る
668 動詞,自立,*,*,一段,命令ｒｏ,着る
669 動詞,自立,*,*,一段,命令ｙｏ,*
670 動詞,自立,*,*,一段,命令ｙｏ,いる
671 動詞,自立,*,*,一段,命令ｙｏ,おける
672 動詞,自立,*,*,一段,命令ｙｏ,できる
673 動詞,自立,*,*,一段,命令ｙｏ,出る
674 動詞,自立,*,*,一段,命令ｙｏ,出来る
675 動詞,自立,*,*,一段,命令ｙｏ,着る
676 動詞,自立,*,*,一段,基本形,*
677 動詞,自立,*,*,一段,基本形,いる
678 動詞,自立,*,*,一段,基本形,おける
679 動詞,自立,*,*,一段,基本形,できる
680 動詞,自立,*,*,一段,基本形,出る
681 動詞,自立,*,*,一段,基本形,出来る
682 動詞,自立,*,*,一段,基本形,着る
683 動詞,自立,*,*,一段,未然ウ接続,*
684 動詞,自立,*,*,一段,未然ウ接続,いる
685 動詞,自立,*,*,一段,未然ウ接続,おける
686 動詞,自立,*,*,一段,未然ウ接続,できる
687 動詞,自立,*,*,一段,未然ウ接続,出る
688 動詞,自立,*,*,一段,未然ウ接続,出来る
689 動詞,自立,*,*,一段,未然ウ接続,着る
690 動詞,自立,*,*,一段,未然形,*
691 動詞,自立,*,*,一段,未然形,いる
692 動詞,自立,*,*,一段,未然形,おける
693 動詞,自立,*,*,一段,未然形,できる
694 動詞,自立,*,*,一段,未然形,出る
695 動詞,自立,*,*,一段,未然形,出来る
696 動詞,自立,*,*,一段,未然形,着る
697 動詞,自立,*,*,一段,連用形,*
698 動詞,自立,*,*,一段,連用形,いる
699 動詞,自立,*,*,一段,連用形,おける
700 動詞,自立,*,*,一段,連用形,できる
701 動詞,自立,*,*,一段,連用形,出る
702 動詞,自立,*,*,一段,連用形,出来る
703 動詞,自立,*,*,一段,連用形,着る
704 動詞,自立,*,*,一段・クレル,仮定形,*
705 動詞,自立,*,*,一段・クレル,仮定縮約１,*
706 動詞,自立,*,*,一段・クレル,命令ｅ,*
707 動詞,自立,*,*,一段・クレル,命令ｒｏ,*
708 動詞,自立,*,*,一段・クレル,命令ｙｏ,*
709 動詞,自立,*,*,一段・クレル,基本形,*
710 動詞,自立,*,*,一段・クレル,未然ウ接続,*
711 動詞,自立,*,*,一段・クレル,未然形,*
712 動詞,自立,*,*,一段・クレル,未然特殊,*
713 動詞,自立,*,*,一段・クレル,連用形,*
714 動詞,自立,*,*,一段・得ル,仮定形,*
715 動詞,自立,*,*,一段・得ル,基本形,*
716 動詞,自立,*,*,五段・カ行イ音便,仮定形,*
717 動詞,自立,*,*,五段・カ行イ音便,仮定縮約１,*
718 動詞,自立,*,*,五段・カ行イ音便,命令ｅ,*
719 動詞,自立,*,*,五段・カ行イ音便,基本形,*
720 動詞,自立,*,*,五段・カ行イ音便,未然ウ接続,*
721 動詞,自立,*,*,五段・カ行イ音便,未然形,*
722 動詞,自立,*,*,五段・カ行イ音便,連用タ接続,*
723 動詞,自立,*,*,五段・カ行イ音便,連用形,*
724 動詞,自立,*,*,五段・カ行促音便,仮定形,行く
725 動詞,自立,*,*,五段・カ行促音便,仮定縮約１,行く
726 動詞,自立,*,*,五段・カ行促音便,命令ｅ,行く
727 動詞,自立,*,*,五段・カ行促音便,基本形,行く
728 動詞,自立,*,*,五段・カ行促音便,未然ウ接続,行く
729 動詞,自立,*,*,五段・カ行促音便,未然形,行く
730 動詞,自立,*,*,五段・カ行促音便,連用タ接続,行く
731 動詞,自立,*,*,五段・カ行促音便,連用形,行く
732 動詞,自立,*,*,五段・カ行促音便ユク,仮定形,*
733 動詞,自立,*,*,五段・カ行促音便ユク,仮定縮約１,*
734 動詞,自立,*,*,五段・カ行促音便ユク,命令ｅ,*
735 動詞,自立,*,*,五段・カ行促音便ユク,基本形,*
736 動詞,自立,*,*,五段・カ行促音便ユク,未然ウ接続,*
737 動詞,自立,*,*,五段・カ行促音便ユク,未然形,*
738 動詞,自立,*,*,五段・カ行促音便ユク,連用形,*
739 動詞,自立,*,*,五段・ラ行,仮定形,ある
740 動詞,自立,*,*,五段・ラ行,仮定形,いる
741 動詞,自立,*,*,五段・ラ行,仮定形,なる
742 動詞,自立,*,*,五段・ラ行,仮定形,依る
743 動詞,自立,*,*,五段・ラ行,仮定縮約１,ある
744 動詞,自立,*,*,五段・ラ行,仮定縮約１,いる
745 動詞,自立,*,*,五段・ラ行,仮定縮約１,なる
746 動詞,自立,*,*,五段・ラ行,仮定縮約１,依る
747 動詞,自立,*,*,五段・ラ行,体言接続特殊,ある
748 動詞,自立,*,*,五段・ラ行,体言接続特殊,いる
749 動詞,自立,*,*,五段・ラ行,体言接続特殊,なる
750 動詞,自立,*,*,五段・ラ行,体言接続特殊,依る
751 動詞,自立,*,*,五段・ラ行,体言接続特殊２,ある
752 動詞,自立,*,*,五段・ラ行,体言接続特殊２,いる
753 動詞,自立,*,*,五段・ラ行,体言接続特殊２,なる
754 動詞,自立,*,*,五段・ラ行,体言接続特殊２,依る
755 動詞,自立,*,*,五段・ラ行,命令ｅ,ある
756 動詞,自立,*,*,五段・ラ行,命令ｅ,いる
757 動詞,自立,*,*,五段・ラ行,命令ｅ,なる
758 動詞,自立,*,*,五段・ラ行,命令ｅ,依る
759 動詞,自立,*,*,五段・ラ行,基本形,ある
760 動詞,自立,*,*,五段・ラ行,基本形,いる
761 動詞,自立,*,*,五段・ラ行,基本形,なる
762 動詞,自立,*,*,五段・ラ行,基本形,依る
763 動詞,自立,*,*,五段・ラ行,未然ウ接続,ある
764 動詞,自立,*,*,五段・ラ行,未然ウ接続,いる
765 動詞,自立,*,*,五段・ラ行,未然ウ接続,なる
766 動詞,自立,*,*,五段・ラ行,未然ウ接続,依る
767 動詞,自立,*,*,五段・ラ行,未然形,ある
768 動詞,自立,*,*,五段・ラ行,未然形,いる
769 動詞,自立,*,*,五段・ラ行,未然形,なる
770 動詞,自立,*,*,五段・ラ行,未然形,依る
771 動詞,自立,*,*,五段・ラ行,未然特殊,ある
772 動詞,自立,*,*,五段・ラ行,未然特殊,いる
773 動詞,自立,*,*,五段・ラ行,未然特殊,なる
774 動詞,自立,*,*,五段・ラ行,未然特殊,依る
775 動詞,自立,*,*,五段・ラ行,連用タ接続,ある
776 動詞,自立,*,*,五段・ラ行,連用タ接続,いる
777 動詞,自立,*,*,五段・ラ行,連用タ接続,なる
778 動詞,自立,*,*,五段・ラ行,連用タ接続,依る
779 動詞,自立,*,*,五段・ラ行,連用形,ある
780 動詞,自立,*,*,五段・ラ行,連用形,いる
781 動詞,自立,*,*,五段・ラ行,連用形,なる
782 動詞,自立,*,*,五段・ラ行,連用形,依る
783 動詞,自立,*,*,五段・ラ行特殊,仮定形,*
784 動詞,自立,*,*,五段・ラ行特殊,仮定縮約１,*
785 動詞,自立,*,*,五段・ラ行特殊,命令ｅ,*
786 動詞,自立,*,*,五段・ラ行特殊,命令ｉ,*
787 動詞,自立,*,*,五段・ラ行特殊,基本形,*
788 動詞,自立,*,*,五段・ラ行特殊,未然ウ接続,*
789 動詞,自立,*,*,五段・ラ行特殊,未然形,*
790 動詞,自立,*,*,五段・ラ行特殊,未然特殊,*
791 動詞,自立,*,*,五段・ラ行特殊,連用タ接続,*
792 動詞,自立,*,*,五段・ラ行特殊,連用形,*
793 動詞,自立,*,*,五段・ワ行ウ音便,仮定形,*
794 動詞,自立,*,*,五段・ワ行ウ音便,命令ｅ,*
795 動詞,自立,*,*,五段・ワ行ウ音便,基本形,*
796 動詞,自立,*,*,五段・ワ行ウ音便,未然ウ接続,*
797 動詞,自立,*,*,五段・ワ行ウ音便,未然形,*
798 動詞,自立,*,*,五段・ワ行ウ音便,連用タ接続,*
799 動詞,自立,*,*,五段・ワ行ウ音便,連用形,*
800 動詞,自立,*,*,五段・ワ行促音便,仮定形,*
801 動詞,自立,*,*,五段・ワ行促音便,仮定形,いう
802 動詞,自立,*,*,五段・ワ行促音便,仮定形,行う
803 動詞,自立,*,*,五段・ワ行促音便,仮定形,言う
804 動詞,自立,*,*,五段・ワ行促音便,仮定縮約１,*
805 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,*
806 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,いう
807 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,行う
808 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,言う
809 動詞,自立,*,*,五段・ワ行促音便,基本形,*
810 動詞,自立,*,*,五段・ワ行促音便,基本形,いう
811 動詞,自立,*,*,五段・ワ行促音便,基本形,行う
812 動詞,自立,*,*,五段・ワ行促音便,基本形,言う
813 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,*
814 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,いう
815 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,行う
816 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,言う
817 動詞,自立,*,*,五段・ワ行促音便,未然形,*
818 動詞,自立,*,*,五段・ワ行促音便,未然形,いう
819 動詞,自立,*,*,五段・ワ行促音便,未然形,行う
820 動詞,自立,*,*,五段・ワ行促音便,未然形,言う
821 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,*
822 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,いう
823 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,行う
824 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,言う
825 動詞,自立,*,*,五段・ワ行促音便,連用形,*
826 動詞,自立,*,*,五段・ワ行促音便,連用形,いう
827 動詞,自立,*,*,五段・ワ行促音便,連用形,行う
828 動詞,自立,*,*,五段・ワ行促音便,連用形,言う
829 動詞,自立,*,*,五段動詞,仮定形,*
830 動詞,自立,*,*,五段動詞,仮定縮約１,*
831 動詞,自立,*,*,五段動詞,体言接続特殊,*
832 動詞,自立,*,*,五段動詞,命令ｅ,*
833 動詞,自立,*,*,五段動詞,基本形,*
834 動詞,自立,*,*,五段動詞,未然ウ接続,*
835 動詞,自立,*,*,五段動詞,未然形,*
836 動詞,自立,*,*,五段動詞,未然特殊,*
837 動詞,自立,*,*,五段動詞,連用タ接続,*
838 動詞,自立,*,*,五段動詞,連用形,*
839 動詞,自立,*,*,四段・タ行,仮定形,*
840 動詞,自立,*,*,四段・タ行,命令ｅ,*
841 動詞,自立,*,*,四段・タ行,基本形,*
842 動詞,自立,*,*,四段・タ行,未然形,*
843 動詞,自立,*,*,四段・タ行,連用形,*
844 動詞,自立,*,*,文語,仮定形,*
845 動詞,自立,*,*,文語,体言接続,*
846 動詞,自立,*,*,文語,命令ｅ,*
847 動詞,自立,*,*,文語,命令ｙｏ,*
848 動詞,自立,*,*,文語,基本形,*
849 動詞,自立,*,*,文語,未然ウ接続,*
850 動詞,自立,*,*,文語,未然形,*
851 動詞,自立,*,*,文語,現代基本形,*
852 動詞,自立,*,*,文語,連用形,*
853 動詞,非自立,*,*,カ変・クル,仮定形,くる
854 動詞,非自立,*,*,カ変・クル,仮定縮約１,くる
855 動詞,非自立,*,*,カ変・クル,体言接続特殊,くる
856 動詞,非自立,*,*,カ変・クル,体言接続特殊２,くる
857 動詞,非自立,*,*,カ変・クル,命令ｉ,くる
858 動詞,非自立,*,*,カ変・クル,命令ｙｏ,くる
859 動詞,非自立,*,*,カ変・クル,基本形,くる
860 動詞,非自立,*,*,カ変・クル,未然ウ接続,くる
861 動詞,非自立,*,*,カ変・クル,未然形,くる
862 動詞,非自立,*,*,カ変・クル,連用形,くる
863 動詞,非自立,*,*,カ変・来ル,仮定形,来る
864 動詞,非自立,*,*,カ変・来ル,仮定縮約１,来る
865 動詞,非自立,*,*,カ変・来ル,体言接続特殊,来る
866 動詞,非自立,*,*,カ変・来ル,体言接続特殊２,来る
867 動詞,非自立,*,*,カ変・来ル,命令ｉ,来る
868 動詞,非自立,*,*,カ変・来ル,命令ｙｏ,来る
869 動詞,非自立,*,*,カ変・来ル,基本形,来る
870 動詞,非自立,*,*,カ変・来ル,未然ウ接続,来る
871 動詞,非自立,*,*,カ変・来ル,未然形,来る
872 動詞,非自立,*,*,カ変・来ル,連用形,来る
873 動詞,非自立,*,*,一段,仮定形,あげる
874 動詞,非自立,*,*,一段,仮定形,いける
875 動詞,非自立,*,*,一段,仮定形,いる
876 動詞,非自立,*,*,一段,仮定形,える
877 動詞,非自立,*,*,一段,仮定形,かえる
878 動詞,非自立,*,*,一段,仮定形,かける
879 動詞,非自立,*,*,一段,仮定形,かねる
880 動詞,非自立,*,*,一段,仮定形,きれる
881 動詞,非自立,*,*,一段,仮定形,すぎる
882 動詞,非自立,*,*,一段,仮定形,そこねる
883 動詞,非自立,*,*,一段,仮定形,そびれる
884 動詞,非自立,*,*,一段,仮定形,たげる
885 動詞,非自立,*,*,一段,仮定形,つける
886 動詞,非自立,*,*,一段,仮定形,つづける
887 動詞,非自立,*,*,一段,仮定形,づける
888 動詞,非自立,*,*,一段,仮定形,てる
889 動詞,非自立,*,*,一段,仮定形,できる
890 動詞,非自立,*,*,一段,仮定形,でる
891 動詞,非自立,*,*,一段,仮定形,のける
892 動詞,非自立,*,*,一段,仮定形,はじめる
893 動詞,非自立,*,*,一段,仮定形,みせる
894 動詞,非自立,*,*,一段,仮定形,みる
895 動詞,非自立,*,*,一段,仮定形,もらえる
896 動詞,非自立,*,*,一段,仮定形,る
897 動詞,非自立,*,*,一段,仮定形,上げる
898 動詞,非自立,*,*,一段,仮定形,代える
899 動詞,非自立,*,*,一段,仮定形,切れる
900 動詞,非自立,*,*,一段,仮定形,変える
901 動詞,非自立,*,*,一段,仮定形,始める
902 動詞,非自立,*,*,一段,仮定形,得る
903 動詞,非自立,*,*,一段,仮定形,忘れる
904 動詞,非自立,*,*,一段,仮定形,惚れる
905 動詞,非自立,*,*,一段,仮定形,振れる
906 動詞,非自立,*,*,一段,仮定形,換える
907 動詞,非自立,*,*,一段,仮定形,替える
908 動詞,非自立,*,*,一段,仮定形,枯れる
909 動詞,非自立,*,*,一段,仮定形,染みる
910 動詞,非自立,*,*,一段,仮定形,終える
911 動詞,非自立,*,*,一段,仮定形,続ける
912 動詞,非自立,*,*,一段,仮定形,過ぎる
913 動詞,非自立,*,*,一段,仮定形,願える
914 動詞,非自立,*,*,一段,仮定縮約１,あげる
915 動詞,非自立,*,*,一段,仮定縮約１,いける
916 動詞,非自立,*,*,一段,仮定縮約１,いる
917 動詞,非自立,*,*,一段,仮定縮約１,える
918 動詞,非自立,*,*,一段,仮定縮約１,かえる
919 動詞,非自立,*,*,一段,仮定縮約１,かける
920 動詞,非自立,*,*,一段,仮定縮約１,かねる
921 動詞,非自立,*,*,一段,仮定縮約１,きれる
922 動詞,非自立,*,*,一段,仮定縮約１,すぎる
923 動詞,非自立,*,*,一段,仮定縮約１,そこねる
924 動詞,非自立,*,*,一段,仮定縮約１,そびれる
925 動詞,非自立,*,*,一段,仮定縮約１,たげる
926 動詞,非自立,*,*,一段,仮定縮約１,つける
927 動詞,非自立,*,*,一段,仮定縮約１,つづける
928 動詞,非自立,*,*,一段,仮定縮約１,づける
929 動詞,非自立,*,*,一段,仮定縮約１,てる
930 動詞,非自立,*,*,一段,仮定縮約１,できる
931 動詞,非自立,*,*,一段,仮定縮約１,でる
932 動詞,非自立,*,*,一段,仮定縮約１,のける
933 動詞,非自立,*,*,一段,仮定縮約１,はじめる
934 動詞,非自立,*,*,一段,仮定縮約１,みせる
935 動詞,非自立,*,*,一段,仮定縮約１,みる
936 動詞,非自立,*,*,一段,仮定縮約１,もらえる
937 動詞,非自立,*,*,一段,仮定縮約１,る
938 動詞,非自立,*,*,一段,仮定縮約１,上げる
939 動詞,非自立,*,*,一段,仮定縮約１,代える
940 動詞,非自立,*,*,一段,仮定縮約１,切れる
941 動詞,非自立,*,*,一段,仮定縮約１,変える
942 動詞,非自立,*,*,一段,仮定縮約１,始める
943 動詞,非自立,*,*,一段,仮定縮約１,得る
944 動詞,非自立,*,*,一段,仮定縮約１,忘れる
945 動詞,非自立,*,*,一段,仮定縮約１,惚れる
946 動詞,非自立,*,*,一段,仮定縮約１,振れる
947 動詞,非自立,*,*,一段,仮定縮約１,換える
948 動詞,非自立,*,*,一段,仮定縮約１,替える
949 動詞,非自立,*,*,一段,仮定縮約１,枯れる
950 動詞,非自立,*,*,一段,仮定縮約１,染みる
951 動詞,非自立,*,*,一段,仮定縮約１,終える
952 動詞,非自立,*,*,一段,仮定縮約１,続ける
953 動詞,非自立,*,*,一段,仮定縮約１,過ぎる
954 動詞,非自立,*,*,一段,仮定縮約１,願える
955 動詞,非自立,*,*,一段,体言接続特殊,あげる
956 動詞,非自立,*,*,一段,体言接続特殊,いける
957 動詞,非自立,*,*,一段,体言接続特殊,いる
958 動詞,非自立,*,*,一段,体言接続特殊,える
959 動詞,非自立,*,*,一段,体言接続特殊,かえる
960 動詞,非自立,*,*,一段,体言接続特殊,かける
961 動詞,非自立,*,*,一段,体言接続特殊,かねる
962 動詞,非自立,*,*,一段,体言接続特殊,きれる
963 動詞,非自立,*,*,一段,体言接続特殊,すぎる
964 動詞,非自立,*,*,一段,体言接続特殊,そこねる
965 動詞,非自立,*,*,一段,体言接続特殊,そびれる
966 動詞,非自立,*,*,一段,体言接続特殊,たげる
967 動詞,非自立,*,*,一段,体言接続特殊,つける
968 動詞,非自立,*,*,一段,体言接続特殊,つづける
969 動詞,非自立,*,*,一段,体言接続特殊,づける
970 動詞,非自立,*,*,一段,体言接続特殊,てる
971 動詞,非自立,*,*,一段,体言接続特殊,できる
972 動詞,非自立,*,*,一段,体言接続特殊,でる
973 動詞,非自立,*,*,一段,体言接続特殊,のける
974 動詞,非自立,*,*,一段,体言接続特殊,はじめる
975 動詞,非自立,*,*,一段,体言接続特殊,みせる
976 動詞,非自立,*,*,一段,体言接続特殊,みる
977 動詞,非自立,*,*,一段,体言接続特殊,もらえる
978 動詞,非自立,*,*,一段,体言接続特殊,る
979 動詞,非自立,*,*,一段,体言接続特殊,上げる
980 動詞,非自立,*,*,一段,体言接続特殊,代える
981 動詞,非自立,*,*,一段,体言接続特殊,切れる
982 動詞,非自立,*,*,一段,体言接続特殊,変える
983 動詞,非自立,*,*,一段,体言接続特殊,始める
984 動詞,非自立,*,*,一段,体言接続特殊,得る
985 動詞,非自立,*,*,一段,体言接続特殊,忘れる
986 動詞,非自立,*,*,一段,体言接続特殊,惚れる
987 動詞,非自立,*,*,一段,体言接続特殊,振れる
988 動詞,非自立,*,*,一段,体言接続特殊,換える
989 動詞,非自立,*,*,一段,体言接続特殊,替える
990 動詞,非自立,*,*,一段,体言接続特殊,枯れる
991 動詞,非自立,*,*,一段,体言接続特殊,染みる
992 動詞,非自立,*,*,一段,体言接続特殊,終える
993 動詞,非自立,*,*,一段,体言接続特殊,続ける
994 動詞,非自立,*,*,一段,体言接続特殊,過ぎる
995 動詞,非自立,*,*,一段,体言接続特殊,願える
996 動詞,非自立,*,*,一段,命令ｒｏ,あげる
997 動詞,非自立,*,*,一段,命令ｒｏ,いける
998 動詞,非自立,*,*,一段,命令ｒｏ,いる
999 動詞,非自立,*,*,一段,命令ｒｏ,える
1000 動詞,非自立,*,*,一段,命令ｒｏ,かえる
1001 動詞,非自立,*,*,一段,命令ｒｏ,かける
1002 動詞,非自立,*,*,一段,命令ｒｏ,かねる
1003 動詞,非自立,*,*,一段,命令ｒｏ,きれる
1004 動詞,非自立,*,*,一段,命令ｒｏ,すぎる
1005 動詞,非自立,*,*,一段,命令ｒｏ,そこねる
1006 動詞,非自立,*,*,一段,命令ｒｏ,そびれる
1007 動詞,非自立,*,*,一段,命令ｒｏ,たげる
1008 動詞,非自立,*,*,一段,命令ｒｏ,つける
1009 動詞,非自立,*,*,一段,命令ｒｏ,つづける
1010 動詞,非自立,*,*,一段,命令ｒｏ,づける
1011 動詞,非自立,*,*,一段,命令ｒｏ,てる
1012 動詞,非自立,*,*,一段,命令ｒｏ,できる
1013 動詞,非自立,*,*,一段,命令ｒｏ,でる
1014 動詞,非自立,*,*,一段,命令ｒｏ,のける
1015 動詞,非自立,*,*,一段,命令ｒｏ,はじめる
1016 動詞,非自立,*,*,一段,命令ｒｏ,みせる
1017 動詞,非自立,*,*,一段,命令ｒｏ,みる
1018 動詞,非自立,*,*,一段,命令ｒｏ,もらえる
1019 動詞,非自立,*,*,一段,命令ｒｏ,る
1020 動詞,非自立,*,*,一段,命令ｒｏ,上げる
1021 動詞,非自立,*,*,一段,命令ｒｏ,代える
1022 動詞,非自立,*,*,一段,命令ｒｏ,切れる
1023 動詞,非自立,*,*,一段,命令ｒｏ,変える
1024 動詞,非自立,*,*,一段,命令ｒｏ,始める
1025 動詞,非自立,*,*,一段,命令ｒｏ,得る
1026 動詞,非自立,*,*,一段,命令ｒｏ,忘れる
1027 動詞,非自立,*,*,一段,命令ｒｏ,惚れる
1028 動詞,非自立,*,*,一段,命令ｒｏ,振れる
1029 動詞,非自立,*,*,一段,命令ｒｏ,換える
1030 動詞,非自立,*,*,一段,命令ｒｏ,替える
1031 動詞,非自立,*,*,一段,命令ｒｏ,枯れる
1032 動詞,非自立,*,*,一段,命令ｒｏ,染みる
1033 動詞,非自立,*,*,一段,命令ｒｏ,終える
1034 動詞,非自立,*,*,一段,命令ｒｏ,続ける
1035 動詞,非自立,*,*,一段,命令ｒｏ,過ぎる
1036 動詞,非自立,*,*,一段,命令ｒｏ,願える
1037 動詞,非自立,*,*,一段,命令ｙｏ,あげる
1038 動詞,非自立,*,*,一段,命令ｙｏ,いける
1039 動詞,非自立,*,*,一段,命令ｙｏ,いる
1040 動詞,非自立,*,*,一段,命令ｙｏ,える
1041 動詞,非自立,*,*,一段,命令ｙｏ,かえる
1042 動詞,非自立,*,*,一段,命令ｙｏ,かける
1043 動詞,非自立,*,*,一段,命令ｙｏ,かねる
1044 動詞,非自立,*,*,一段,命令ｙｏ,きれる
1045 動詞,非自立,*,*,一段,命令ｙｏ,すぎる
1046 動詞,非自立,*,*,一段,命令ｙｏ,そこねる
1047 動詞,非自立,*,*,一段,命令ｙｏ,そびれる
1048 動詞,非自立,*,*,一段,命令ｙｏ,たげる
1049 動詞,非自立,*,*,一段,命令ｙｏ,つける
1050 動詞,非自立,*,*,一段,命令ｙｏ,つづける
1051 動詞,非自立,*,*,一段,命令ｙｏ,づける
1052 動詞,非自立,*,*,一段,命令ｙｏ,てる
1053 動詞,非自立,*,*,一段,命令ｙｏ,できる
1054 動詞,非自立,*,*,一段,命令ｙｏ,でる
1055 動詞,非自立,*,*,一段,命令ｙｏ,のける
1056 動詞,非自立,*,*,一段,命令ｙｏ,はじめる
1057 動詞,非自立,*,*,一段,命令ｙｏ,みせる
1058 動詞,非自立,*,*,一段,命令ｙｏ,みる
1059 動詞,非自立,*,*,一段,命令ｙｏ,もらえる
1060 動詞,非自立,*,*,一段,命令ｙｏ,る
1061 動詞,非自立,*,*,一段,命令ｙｏ,上げる
1062 動詞,非自立,*,*,一段,命令ｙｏ,代える
1063 動詞,非自立,*,*,一段,命令ｙｏ,切れる
1064 動詞,非自立,*,*,一段,命令ｙｏ,変える
1065 動詞,非自立,*,*,一段,命令ｙｏ,始める
1066 動詞,非自立,*,*,一段,命令ｙｏ,得る
1067 動詞,非自立,*,*,一段,命令ｙｏ,忘れる
1068 動詞,非自立,*,*,一段,命令ｙｏ,惚れる
1069 動詞,非自立,*,*,一段,命令ｙｏ,振れる
1070 動詞,非自立,*,*,一段,命令ｙｏ,換える
1071 動詞,非自立,*,*,一段,命令ｙｏ,替える
1072 動詞,非自立,*,*,一段,命令ｙｏ,枯れる
1073 動詞,非自立,*,*,一段,命令ｙｏ,染みる
1074 動詞,非自立,*,*,一段,命令ｙｏ,終える
1075 動詞,非自立,*,*,一段,命令ｙｏ,続ける
1076 動詞,非自立,*,*,一段,命令ｙｏ,過ぎる
1077 動詞,非自立,*,*,一段,命令ｙｏ,願える
1078 動詞,非自立,*,*,一段,基本形,あげる
1079 動詞,非自立,*,*,一段,基本形,いける
1080 動詞,非自立,*,*,一段,基本形,いる
1081 動詞,非自立,*,*,一段,基本形,える
1082 動詞,非自立,*,*,一段,基本形,かえる
1083 動詞,非自立,*,*,一段,基本形,かける
1084 動詞,非自立,*,*,一段,基本形,かねる
1085 動詞,非自立,*,*,一段,基本形,きれる
1086 動詞,非自立,*,*,一段,基本形,すぎる
1087 動詞,非自立,*,*,一段,基本形,そこねる
1088 動詞,非自立,*,*,一段,基本形,そびれる
1089 動詞,非自立,*,*,一段,基本形,たげる
1090 動詞,非自立,*,*,一段,基本形,つける
1091 動詞,非自立,*,*,一段,基本形,つづける
1092 動詞,非自立,*,*,一段,基本形,づける
1093 動詞,非自立,*,*,一段,基本形,てる
1094 動詞,非自立,*,*,一段,基本形,できる
1095 動詞,非自立,*,*,一段,基本形,でる
1096 動詞,非自立,*,*,一段,基本形,のける
1097 動詞,非自立,*,*,一段,基本形,はじめる
1098 動詞,非自立,*,*,一段,基本形,みせる
1099 動詞,非自立,*,*,一段,基本形,みる
1100 動詞,非自立,*,*,一段,基本形,もらえる
1101 動詞,非自立,*,*,一段,基本形,る
1102 動詞,非自立,*,*,一段,基本形,上げる
1103 動詞,非自立,*,*,一段,基本形,代える
1104 動詞,非自立,*,*,一段,基本形,切れる
1105 動詞,非自立,*,*,一段,基本形,変える
1106 動詞,非自立,*,*,一段,基本形,始める
1107 動詞,非自立,*,*,一段,基本形,得る
1108 動詞,非自立,*,*,一段,基本形,忘れる
1109 動詞,非自立,*,*,一段,基本形,惚れる
1110 動詞,非自立,*,*,一段,基本形,振れる
1111 動詞,非自立,*,*,一段,基本形,換える
1112 動詞,非自立,*,*,一段,基本形,替える
1113 動詞,非自立,*,*,一段,基本形,枯れる
1114 動詞,非自立,*,*,一段,基本形,染みる
1115 動詞,非自立,*,*,一段,基本形,終える
1116 動詞,非自立,*,*,一段,基本形,続ける
1117 動詞,非自立,*,*,一段,基本形,過ぎる
1118 動詞,非自立,*,*,一段,基本形,願える
1119 動詞,非自立,*,*,一段,未然ウ接続,あげる
1120 動詞,非自立,*,*,一段,未然ウ接続,いける
1121 動詞,非自立,*,*,一段,未然ウ接続,いる
1122 動詞,非自立,*,*,一段,未然ウ接続,える
1123 動詞,非自立,*,*,一段,未然ウ接続,かえる
1124 動詞,非自立,*,*,一段,未然ウ接続,かける
1125 動詞,非自立,*,*,一段,未然ウ接続,かねる
1126 動詞,非自立,*,*,一段,未然ウ接続,きれる
1127 動詞,非自立,*,*,一段,未然ウ接続,すぎる
1128 動詞,非自立,*,*,一段,未然ウ接続,そこねる
1129 動詞,非自立,*,*,一段,未然ウ接続,そびれる
1130 動詞,非自立,*,*,一段,未然ウ接続,たげる
1131 動詞,非自立,*,*,一段,未然ウ接続,つける
1132 動詞,非自立,*,*,一段,未然ウ接続,つづける
1133 動詞,非自立,*,*,一段,未然ウ接続,づける
1134 動詞,非自立,*,*,一段,未然ウ接続,てる
1135 動詞,非自立,*,*,一段,未然ウ接続,できる
1136 動詞,非自立,*,*,一段,未然ウ接続,でる
1137 動詞,非自立,*,*,一段,未然ウ接続,のける
1138 動詞,非自立,*,*,一段,未然ウ接続,はじめる
1139 動詞,非自立,*,*,一段,未然ウ接続,みせる
1140 動詞,非自立,*,*,一段,未然ウ接続,みる
1141 動詞,非自立,*,*,一段,未然ウ接続,もらえる
1142 動詞,非自立,*,*,一段,未然ウ接続,る
1143 動詞,非自立,*,*,一段,未然ウ接続,上げる
1144 動詞,非自立,*,*,一段,未然ウ接続,代える
1145 動詞,非自立,*,*,一段,未然ウ接続,切れる
1146 動詞,非自立,*,*,一段,未然ウ接続,変える
1147 動詞,非自立,*,*,一段,未然ウ接続,始める
1148 動詞,非自立,*,*,一段,未然ウ接続,得る
1149 動詞,非自立,*,*,一段,未然ウ接続,忘れる
1150 動詞,非自立,*,*,一段,未然ウ接続,惚れる
1151 動詞,非自立,*,*,一段,未然ウ接続,振れる
1152 動詞,非自立,*,*,一段,未然ウ接続,換える
1153 動詞,非自立,*,*,一段,未然ウ接続,替える
1154 動詞,非自立,*,*,一段,未然ウ接続,枯れる
1155 動詞,非自立,*,*,一段,未然ウ接続,染みる
1156 動詞,非自立,*,*,一段,未然ウ接続,終える
1157 動詞,非自立,*,*,一段,未然ウ接続,続ける
1158 動詞,非自立,*,*,一段,未然ウ接続,過ぎる
1159 動詞,非自立,*,*,一段,未然ウ接続,願える
1160 動詞,非自立,*,*,一段,未然形,あげる
1161 動詞,非自立,*,*,一段,未然形,いける
1162 動詞,非自立,*,*,一段,未然形,いる
1163 動詞,非自立,*,*,一段,未然形,える
1164 動詞,非自立,*,*,一段,未然形,かえる
1165 動詞,非自立,*,*,一段,未然形,かける
1166 動詞,非自立,*,*,一段,未然形,かねる
1167 動詞,非自立,*,*,一段,未然形,きれる
1168 動詞,非自立,*,*,一段,未然形,すぎる
1169 動詞,非自立,*,*,一段,未然形,そこねる
1170 動詞,非自立,*,*,一段,未然形,そびれる
1171 動詞,非自立,*,*,一段,未然形,たげる
1172 動詞,非自立,*,*,一段,未然形,つける
1173 動詞,非自立,*,*,一段,未然形,つづける
1174 動詞,非自立,*,*,一段,未然形,づける
1175 動詞,非自立,*,*,一段,未然形,てる
1176 動詞,非自立,*,*,一段,未然形,できる
1177 動詞,非自立,*,*,一段,未然形,でる
1178 動詞,非自立,*,*,一段,未然形,のける
1179 動詞,非自立,*,*,一段,未然形,はじめる
1180 動詞,非自立,*,*,一段,未然形,みせる
1181 動詞,非自立,*,*,一段,未然形,みる
1182 動詞,非自立,*,*,一段,未然形,もらえる
1183 動詞,非自立,*,*,一段,未然形,上げる
1184 動詞,非自立,*,*,一段,未然形,代える
1185 動詞,非自立,*,*,一段,未然形,切れる
1186 動詞,非自立,*,*,一段,未然形,変える
1187 動詞,非自立,*,*,一段,未然形,始める
1188 動詞,非自立,*,*,一段,未然形,得る
1189 動詞,非自立,*,*,一段,未然形,忘れる
1190 動詞,非自立,*,*,一段,未然形,惚れる
1191 動詞,非自立,*,*,一段,未然形,振れる
1192 動詞,非自立,*,*,一段,未然形,換える
1193 動詞,非自立,*,*,一段,未然形,替える
1194 動詞,非自立,*,*,一段,未然形,枯れる
1195 動詞,非自立,*,*,一段,未然形,染みる
1196 動詞,非自立,*,*,一段,未然形,終える
1197 動詞,非自立,*,*,一段,未然形,続ける
1198 動詞,非自立,*,*,一段,未然形,過ぎる
1199 動詞,非自立,*,*,一段,未然形,願える
1200 動詞,非自立,*,*,一段,連用形,あげる
1201 動詞,非自立,*,*,一段,連用形,いける
1202 動詞,非自立,*,*,一段,連用形,いる
1203 動詞,非自立,*,*,一段,連用形,える
1204 動詞,非自立,*,*,一段,連用形,かえる
1205 動詞,非自立,*,*,一段,連用形,かける
1206 動詞,非自立,*,*,一段,連用形,かねる
1207 動詞,非自立,*,*,一段,連用形,きれる
1208 動詞,非自立,*,*,一段,連用形,すぎる
1209 動詞,非自立,*,*,一段,連用形,そこねる
1210 動詞,非自立,*,*,一段,連用形,そびれる
1211 動詞,非自立,*,*,一段,連用形,たげる
1212 動詞,非自立,*,*,一段,連用形,つける
1213 動詞,非自立,*,*,一段,連用形,つづける
1214 動詞,非自立,*,*,一段,連用形,づける
1215 動詞,非自立,*,*,一段,連用形,てる
1216 動詞,非自立,*,*,一段,連用形,できる
1217 動詞,非自立,*,*,一段,連用形,でる
1218 動詞,非自立,*,*,一段,連用形,のける
1219 動詞,非自立,*,*,一段,連用形,はじめる
1220 動詞,非自立,*,*,一段,連用形,みせる
1221 動詞,非自立,*,*,一段,連用形,みる
1222 動詞,非自立,*,*,一段,連用形,もらえる
1223 動詞,非自立,*,*,一段,連用形,上げる
1224 動詞,非自立,*,*,一段,連用形,代える
1225 動詞,非自立,*,*,一段,連用形,切れる
1226 動詞,非自立,*,*,一段,連用形,変える
1227 動詞,非自立,*,*,一段,連用形,始める
1228 動詞,非自立,*,*,一段,連用形,得る
1229 動詞,非自立,*,*,一段,連用形,忘れる
1230 動詞,非自立,*,*,一段,連用形,惚れる
1231 動詞,非自立,*,*,一段,連用形,振れる
1232 動詞,非自立,*,*,一段,連用形,換える
1233 動詞,非自立,*,*,一段,連用形,替える
1234 動詞,非自立,*,*,一段,連用形,枯れる
1235 動詞,非自立,*,*,一段,連用形,染みる
1236 動詞,非自立,*,*,一段,連用形,終える
1237 動詞,非自立,*,*,一段,連用形,続ける
1238 動詞,非自立,*,*,一段,連用形,過ぎる
1239 動詞,非自立,*,*,一段,連用形,願える
1240 動詞,非自立,*,*,一段・クレル,仮定形,くれる
1241 動詞,非自立,*,*,一段・クレル,仮定縮約１,くれる
1242 動詞,非自立,*,*,一段・クレル,命令ｅ,くれる
1243 動詞,非自立,*,*,一段・クレル,命令ｒｏ,くれる
1244 動詞,非自立,*,*,一段・クレル,命令ｙｏ,くれる
1245 動詞,非自立,*,*,一段・クレル,基本形,くれる
1246 動詞,非自立,*,*,一段・クレル,未然ウ接続,くれる
1247 動詞,非自立,*,*,一段・クレル,未然形,くれる
1248 動詞,非自立,*,*,一段・クレル,未然特殊,くれる
1249 動詞,非自立,*,*,一段・クレル,連用形,くれる
1250 動詞,非自立,*,*,一段・得ル,仮定形,うる
1251 動詞,非自立,*,*,一段・得ル,仮定形,得る
1252 動詞,非自立,*,*,一段・得ル,基本形,うる
1253 動詞,非自立,*,*,一段・得ル,基本形,得る
1254 動詞,非自立,*,*,五段・カ行イ音便,仮定形,いただく
1255 動詞,非自立,*,*,五段・カ行イ音便,仮定形,おく
1256 動詞,非自立,*,*,五段・カ行イ音便,仮定形,とく
1257 動詞,非自立,*,*,五段・カ行イ音便,仮定形,どく
1258 動詞,非自立,*,*,五段・カ行イ音便,仮定形,ぬく
1259 動詞,非自立,*,*,五段・カ行イ音便,仮定形,めく
1260 動詞,非自立,*,*,五段・カ行イ音便,仮定形,付く
1261 動詞,非自立,*,*,五段・カ行イ音便,仮定形,抜く
1262 動詞,非自立,*,*,五段・カ行イ音便,仮定形,炊く
1263 動詞,非自立,*,*,五段・カ行イ音便,仮定形,焚く
1264 動詞,非自立,*,*,五段・カ行イ音便,仮定形,続く
1265 動詞,非自立,*,*,五段・カ行イ音便,仮定形,頂く
1266 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,いただく
1267 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,おく
1268 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,とく
1269 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,どく
1270 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,ぬく
1271 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,めく
1272 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,付く
1273 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,抜く
1274 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,炊く
1275 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,焚く
1276 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,続く
1277 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,頂く
1278 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,いただく
1279 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,おく
1280 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,とく
1281 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,どく
1282 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,ぬく
1283 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,めく
1284 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,付く
1285 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,抜く
1286 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,炊く
1287 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,焚く
1288 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,続く
1289 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,頂く
1290 動詞,非自立,*,*,五段・カ行イ音便,基本形,いただく
1291 動詞,非自立,*,*,五段・カ行イ音便,基本形,おく
1292 動詞,非自立,*,*,五段・カ行イ音便,基本形,とく
1293 動詞,非自立,*,*,五段・カ行イ音便,基本形,どく
1294 動詞,非自立,*,*,五段・カ行イ音便,基本形,ぬく
1295 動詞,非自立,*,*,五段・カ行イ音便,基本形,めく
1296 動詞,非自立,*,*,五段・カ行イ音便,基本形,付く
1297 動詞,非自立,*,*,五段・カ行イ音便,基本形,抜く
1298 動詞,非自立,*,*,五段・カ行イ音便,基本形,炊く
1299 動詞,非自立,*,*,五段・カ行イ音便,基本形,焚く
1300 動詞,非自立,*,*,五段・カ行イ音便,基本形,続く
1301 動詞,非自立,*,*,五段・カ行イ音便,基本形,頂く
1302 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,いただく
1303 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,おく
1304 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,とく
1305 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,どく
1306 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,ぬく
1307 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,めく
1308 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,付く
1309 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,抜く
1310 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,炊く
1311 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,焚く
1312 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,続く
1313 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,頂く
1314 動詞,非自立,*,*,五段・カ行イ音便,未然形,いただく
1315 動詞,非自立,*,*,五段・カ行イ音便,未然形,おく
1316 動詞,非自立,*,*,五段・カ行イ音便,未然形,とく
1317 動詞,非自立,*,*,五段・カ行イ音便,未然形,どく
1318 動詞,非自立,*,*,五段・カ行イ音便,未然形,ぬく
1319 動詞,非自立,*,*,五段・カ行イ音便,未然形,めく
1320 動詞,非自立,*,*,五段・カ行イ音便,未然形,付く
1321 動詞,非自立,*,*,五段・カ行イ音便,未然形,抜く
1322 動詞,非自立,*,*,五段・カ行イ音便,未然形,炊く
1323 動詞,非自立,*,*,五段・カ行イ音便,未然形,焚く
1324 動詞,非自立,*,*,五段・カ行イ音便,未然形,続く
1325 動詞,非自立,*,*,五段・カ行イ音便,未然形,頂く
1326 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,いただく
1327 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,おく
1328 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,とく
1329 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,どく
1330 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,ぬく
1331 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,めく
1332 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,付く
1333 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,抜く
1334 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,炊く
1335 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,焚く
1336 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,続く
1337 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,頂く
1338 動詞,非自立,*,*,五段・カ行イ音便,連用形,いただく
1339 動詞,非自立,*,*,五段・カ行イ音便,連用形,おく
1340 動詞,非自立,*,*,五段・カ行イ音便,連用形,とく
1341 動詞,非自立,*,*,五段・カ行イ音便,連用形,どく
1342 動詞,非自立,*,*,五段・カ行イ音便,連用形,ぬく
1343 動詞,非自立,*,*,五段・カ行イ音便,連用形,めく
1344 動詞,非自立,*,*,五段・カ行イ音便,連用形,付く
1345 動詞,非自立,*,*,五段・カ行イ音便,連用形,抜く
1346 動詞,非自立,*,*,五段・カ行イ音便,連用形,炊く
1347 動詞,非自立,*,*,五段・カ行イ音便,連用形,焚く
1348 動詞,非自立,*,*,五段・カ行イ音便,連用形,続く
1349 動詞,非自立,*,*,五段・カ行イ音便,連用形,頂く
1350 動詞,非自立,*,*,五段・カ行促音便,仮定形,いく
1351 動詞,非自立,*,*,五段・カ行促音便,仮定形,く
1352 動詞,非自立,*,*,五段・カ行促音便,仮定形,てく
1353 動詞,非自立,*,*,五段・カ行促音便,仮定形,でく
1354 動詞,非自立,*,*,五段・カ行促音便,仮定形,行く
1355 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,いく
1356 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,く
1357 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,てく
1358 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,でく
1359 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,ク
1360 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,行く
1361 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,いく
1362 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,く
1363 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,てく
1364 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,でく
1365 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,行く
1366 動詞,非自立,*,*,五段・カ行促音便,基本形,いく
1367 動詞,非自立,*,*,五段・カ行促音便,基本形,く
1368 動詞,非自立,*,*,五段・カ行促音便,基本形,てく
1369 動詞,非自立,*,*,五段・カ行促音便,基本形,でく
1370 動詞,非自立,*,*,五段・カ行促音便,基本形,行く
1371 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,いく
1372 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,く
1373 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,てく
1374 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,でく
1375 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,行く
1376 動詞,非自立,*,*,五段・カ行促音便,未然形,いく
1377 動詞,非自立,*,*,五段・カ行促音便,未然形,く
1378 動詞,非自立,*,*,五段・カ行促音便,未然形,てく
1379 動詞,非自立,*,*,五段・カ行促音便,未然形,でく
1380 動詞,非自立,*,*,五段・カ行促音便,未然形,行く
1381 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,いく
1382 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,く
1383 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,てく
1384 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,でく
1385 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,行く
1386 動詞,非自立,*,*,五段・カ行促音便,連用形,いく
1387 動詞,非自立,*,*,五段・カ行促音便,連用形,く
1388 動詞,非自立,*,*,五段・カ行促音便,連用形,てく
1389 動詞,非自立,*,*,五段・カ行促音便,連用形,でく
1390 動詞,非自立,*,*,五段・カ行促音便,連用形,行く
1391 動詞,非自立,*,*,五段・カ行促音便ユク,仮定形,ゆく
1392 動詞,非自立,*,*,五段・カ行促音便ユク,仮定形,行く
1393 動詞,非自立,*,*,五段・カ行促音便ユク,仮定縮約１,ゆく
1394 動詞,非自立,*,*,五段・カ行促音便ユク,仮定縮約１,行く
1395 動詞,非自立,*,*,五段・カ行促音便ユク,命令ｅ,ゆく
1396 動詞,非自立,*,*,五段・カ行促音便ユク,命令ｅ,行く
1397 動詞,非自立,*,*,五段・カ行促音便ユク,基本形,ゆく
1398 動詞,非自立,*,*,五段・カ行促音便ユク,基本形,行く
1399 動詞,非自立,*,*,五段・カ行促音便ユク,未然ウ接続,ゆく
1400 動詞,非自立,*,*,五段・カ行促音便ユク,未然ウ接続,行く
1401 動詞,非自立,*,*,五段・カ行促音便ユク,未然形,ゆく
1402 動詞,非自立,*,*,五段・カ行促音便ユク,未然形,行く
1403 動詞,非自立,*,*,五段・カ行促音便ユク,連用形,ゆく
1404 動詞,非自立,*,*,五段・カ行促音便ユク,連用形,行く
1405 動詞,非自立,*,*,五段・サ行,仮定形,いたす
1406 動詞,非自立,*,*,五段・サ行,仮定形,だす
1407 動詞,非自立,*,*,五段・サ行,仮定形,つくす
1408 動詞,非自立,*,*,五段・サ行,仮定形,なおす
1409 動詞,非自立,*,*,五段・サ行,仮定形,出す
1410 動詞,非自立,*,*,五段・サ行,仮定形,尽くす
1411 動詞,非自立,*,*,五段・サ行,仮定形,直す
1412 動詞,非自立,*,*,五段・サ行,仮定形,致す
1413 動詞,非自立,*,*,五段・サ行,仮定縮約１,いたす
1414 動詞,非自立,*,*,五段・サ行,仮定縮約１,だす
1415 動詞,非自立,*,*,五段・サ行,仮定縮約１,つくす
1416 動詞,非自立,*,*,五段・サ行,仮定縮約１,なおす
1417 動詞,非自立,*,*,五段・サ行,仮定縮約１,出す
1418 動詞,非自立,*,*,五段・サ行,仮定縮約１,尽くす
1419 動詞,非自立,*,*,五段・サ行,仮定縮約１,直す
1420 動詞,非自立,*,*,五段・サ行,仮定縮約１,致す
1421 動詞,非自立,*,*,五段・サ行,命令ｅ,いたす
1422 動詞,非自立,*,*,五段・サ行,命令ｅ,だす
1423 動詞,非自立,*,*,五段・サ行,命令ｅ,つくす
1424 動詞,非自立,*,*,五段・サ行,命令ｅ,なおす
1425 動詞,非自立,*,*,五段・サ行,命令ｅ,出す
1426 動詞,非自立,*,*,五段・サ行,命令ｅ,尽くす
1427 動詞,非自立,*,*,五段・サ行,命令ｅ,直す
1428 動詞,非自立,*,*,五段・サ行,命令ｅ,致す
1429 動詞,非自立,*,*,五段・サ行,基本形,いたす
1430 動詞,非自立,*,*,五段・サ行,基本形,だす
1431 動詞,非自立,*,*,五段・サ行,基本形,つくす
1432 動詞,非自立,*,*,五段・サ行,基本形,なおす
1433 動詞,非自立,*,*,五段・サ行,基本形,出す
1434 動詞,非自立,*,*,五段・サ行,基本形,尽くす
1435 動詞,非自立,*,*,五段・サ行,基本形,直す
1436 動詞,非自立,*,*,五段・サ行,基本形,致す
1437 動詞,非自立,*,*,五段・サ行,未然ウ接続,いたす
1438 動詞,非自立,*,*,五段・サ行,未然ウ接続,だす
1439 動詞,非自立,*,*,五段・サ行,未然ウ接続,つくす
1440 動詞,非自立,*,*,五段・サ行,未然ウ接続,なおす
1441 動詞,非自立,*,*,五段・サ行,未然ウ接続,出す
1442 動詞,非自立,*,*,五段・サ行,未然ウ接続,尽くす
1443 動詞,非自立,*,*,五段・サ行,未然ウ接続,直す
1444 動詞,非自立,*,*,五段・サ行,未然ウ接続,致す
1445 動詞,非自立,*,*,五段・サ行,未然形,いたす
1446 動詞,非自立,*,*,五段・サ行,未然形,だす
1447 動詞,非自立,*,*,五段・サ行,未然形,つくす
1448 動詞,非自立,*,*,五段・サ行,未然形,なおす
1449 動詞,非自立,*,*,五段・サ行,未然形,出す
1450 動詞,非自立,*,*,五段・サ行,未然形,尽くす
1451 動詞,非自立,*,*,五段・サ行,未然形,直す
1452 動詞,非自立,*,*,五段・サ行,未然形,致す
1453 動詞,非自立,*,*,五段・サ行,連用形,いたす
1454 動詞,非自立,*,*,五段・サ行,連用形,だす
1455 動詞,非自立,*,*,五段・サ行,連用形,つくす
1456 動詞,非自立,*,*,五段・サ行,連用形,なおす
1457 動詞,非自立,*,*,五段・サ行,連用形,出す
1458 動詞,非自立,*,*,五段・サ行,連用形,尽くす
1459 動詞,非自立,*,*,五段・サ行,連用形,直す
1460 動詞,非自立,*,*,五段・サ行,連用形,致す
1461 動詞,非自立,*,*,五段・マ行,仮定形,こむ
1462 動詞,非自立,*,*,五段・マ行,仮定形,込む
1463 動詞,非自立,*,*,五段・マ行,仮定縮約１,こむ
1464 動詞,非自立,*,*,五段・マ行,仮定縮約１,込む
1465 動詞,非自立,*,*,五段・マ行,命令ｅ,こむ
1466 動詞,非自立,*,*,五段・マ行,命令ｅ,込む
1467 動詞,非自立,*,*,五段・マ行,基本形,こむ
1468 動詞,非自立,*,*,五段・マ行,基本形,込む
1469 動詞,非自立,*,*,五段・マ行,未然ウ接続,こむ
1470 動詞,非自立,*,*,五段・マ行,未然ウ接続,込む
1471 動詞,非自立,*,*,五段・マ行,未然形,こむ
1472 動詞,非自立,*,*,五段・マ行,未然形,込む
1473 動詞,非自立,*,*,五段・マ行,連用タ接続,こむ
1474 動詞,非自立,*,*,五段・マ行,連用タ接続,込む
1475 動詞,非自立,*,*,五段・マ行,連用形,こむ
1476 動詞,非自立,*,*,五段・マ行,連用形,込む
1477 動詞,非自立,*,*,五段・ラ行,仮定形,ある
1478 動詞,非自立,*,*,五段・ラ行,仮定形,おる
1479 動詞,非自立,*,*,五段・ラ行,仮定形,かかる
1480 動詞,非自立,*,*,五段・ラ行,仮定形,きる
1481 動詞,非自立,*,*,五段・ラ行,仮定形,たる
1482 動詞,非自立,*,*,五段・ラ行,仮定形,だる
1483 動詞,非自立,*,*,五段・ラ行,仮定形,とる
1484 動詞,非自立,*,*,五段・ラ行,仮定形,どる
1485 動詞,非自立,*,*,五段・ラ行,仮定形,なる
1486 動詞,非自立,*,*,五段・ラ行,仮定形,はる
1487 動詞,非自立,*,*,五段・ラ行,仮定形,まいる
1488 動詞,非自立,*,*,五段・ラ行,仮定形,まくる
1489 動詞,非自立,*,*,五段・ラ行,仮定形,まわる
1490 動詞,非自立,*,*,五段・ラ行,仮定形,やがる
1491 動詞,非自立,*,*,五段・ラ行,仮定形,やる
1492 動詞,非自立,*,*,五段・ラ行,仮定形,切る
1493 動詞,非自立,*,*,五段・ラ行,仮定形,参る
1494 動詞,非自立,*,*,五段・ラ行,仮定形,取る
1495 動詞,非自立,*,*,五段・ラ行,仮定形,回る
1496 動詞,非自立,*,*,五段・ラ行,仮定形,終わる
1497 動詞,非自立,*,*,五段・ラ行,仮定縮約１,ある
1498 動詞,非自立,*,*,五段・ラ行,仮定縮約１,おる
1499 動詞,非自立,*,*,五段・ラ行,仮定縮約１,かかる
1500 動詞,非自立,*,*,五段・ラ行,仮定縮約１,きる
1501 動詞,非自立,*,*,五段・ラ行,仮定縮約１,たる
1502 動詞,非自立,*,*,五段・ラ行,仮定縮約１,だる
1503 動詞,非自立,*,*,五段・ラ行,仮定縮約１,とる
1504 動詞,非自立,*,*,五段・ラ行,仮定縮約１,どる
1505 動詞,非自立,*,*,五段・ラ行,仮定縮約１,なる
1506 動詞,非自立,*,*,五段・ラ行,仮定縮約１,はる
1507 動詞,非自立,*,*,五段・ラ行,仮定縮約１,まいる
1508 動詞,非自立,*,*,五段・ラ行,仮定縮約１,まくる
1509 動詞,非自立,*,*,五段・ラ行,仮定縮約１,まわる
1510 動詞,非自立,*,*,五段・ラ行,仮定縮約１,やがる
1511 動詞,非自立,*,*,五段・ラ行,仮定縮約１,やる
1512 動詞,非自立,*,*,五段・ラ行,仮定縮約１,ドル
1513 動詞,非自立,*,*,五段・ラ行,仮定縮約１,切る
1514 動詞,非自立,*,*,五段・ラ行,仮定縮約１,参る
1515 動詞,非自立,*,*,五段・ラ行,仮定縮約１,取る
1516 動詞,非自立,*,*,五段・ラ行,仮定縮約１,回る
1517 動詞,非自立,*,*,五段・ラ行,仮定縮約１,終わる
1518 動詞,非自立,*,*,五段・ラ行,体言接続特殊,ある
1519 動詞,非自立,*,*,五段・ラ行,体言接続特殊,おる
1520 動詞,非自立,*,*,五段・ラ行,体言接続特殊,かかる
1521 動詞,非自立,*,*,五段・ラ行,体言接続特殊,きる
1522 動詞,非自立,*,*,五段・ラ行,体言接続特殊,たる
1523 動詞,非自立,*,*,五段・ラ行,体言接続特殊,だる
1524 動詞,非自立,*,*,五段・ラ行,体言接続特殊,とる
1525 動詞,非自立,*,*,五段・ラ行,体言接続特殊,どる
1526 動詞,非自立,*,*,五段・ラ行,体言接続特殊,なる
1527 動詞,非自立,*,*,五段・ラ行,体言接続特殊,はる
1528 動詞,非自立,*,*,五段・ラ行,体言接続特殊,まいる
1529 動詞,非自立,*,*,五段・ラ行,体言接続特殊,まくる
1530 動詞,非自立,*,*,五段・ラ行,体言接続特殊,まわる
1531 動詞,非自立,*,*,五段・ラ行,体言接続特殊,やがる
1532 動詞,非自立,*,*,五段・ラ行,体言接続特殊,やる
1533 動詞,非自立,*,*,五段・ラ行,体言接続特殊,切る
1534 動詞,非自立,*,*,五段・ラ行,体言接続特殊,参る
1535 動詞,非自立,*,*,五段・ラ行,体言接続特殊,取る
1536 動詞,非自立,*,*,五段・ラ行,体言接続特殊,回る
1537 動詞,非自立,*,*,五段・ラ行,体言接続特殊,終わる
1538 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,ある
1539 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,おる
1540 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,かかる
1541 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,きる
1542 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,たる
1543 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,とる
1544 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,どる
1545 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,なる
1546 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,はる
1547 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,まいる
1548 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,まくる
1549 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,まわる
1550 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,やる
1551 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,切る
1552 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,参る
1553 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,回る
1554 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,終わる
1555 動詞,非自立,*,*,五段・ラ行,命令ｅ,ある
1556 動詞,非自立,*,*,五段・ラ行,命令ｅ,おる
1557 動詞,非自立,*,*,五段・ラ行,命令ｅ,かかる
1558 動詞,非自立,*,*,五段・ラ行,命令ｅ,きる
1559 動詞,非自立,*,*,五段・ラ行,命令ｅ,たる
1560 動詞,非自立,*,*,五段・ラ行,命令ｅ,だる
1561 動詞,非自立,*,*,五段・ラ行,命令ｅ,とる
1562 動詞,非自立,*,*,五段・ラ行,命令ｅ,どる
1563 動詞,非自立,*,*,五段・ラ行,命令ｅ,なる
1564 動詞,非自立,*,*,五段・ラ行,命令ｅ,はる
1565 動詞,非自立,*,*,五段・ラ行,命令ｅ,まいる
1566 動詞,非自立,*,*,五段・ラ行,命令ｅ,まくる
1567 動詞,非自立,*,*,五段・ラ行,命令ｅ,まわる
1568 動詞,非自立,*,*,五段・ラ行,命令ｅ,やがる
1569 動詞,非自立,*,*,五段・ラ行,命令ｅ,やる
1570 動詞,非自立,*,*,五段・ラ行,命令ｅ,切る
1571 動詞,非自立,*,*,五段・ラ行,命令ｅ,参る
1572 動詞,非自立,*,*,五段・ラ行,命令ｅ,取る
1573 動詞,非自立,*,*,五段・ラ行,命令ｅ,回る
1574 動詞,非自立,*,*,五段・ラ行,命令ｅ,終わる
1575 動詞,非自立,*,*,五段・ラ行,基本形,ある
1576 動詞,非自立,*,*,五段・ラ行,基本形,おる
1577 動詞,非自立,*,*,五段・ラ行,基本形,かかる
1578 動詞,非自立,*,*,五段・ラ行,基本形,きる
1579 動詞,非自立,*,*,五段・ラ行,基本形,たる
1580 動詞,非自立,*,*,五段・ラ行,基本形,だる
1581 動詞,非自立,*,*,五段・ラ行,基本形,とる
1582 動詞,非自立,*,*,五段・ラ行,基本形,どる
1583 動詞,非自立,*,*,五段・ラ行,基本形,なる
1584 動詞,非自立,*,*,五段・ラ行,基本形,はる
1585 動詞,非自立,*,*,五段・ラ行,基本形,まいる
1586 動詞,非自立,*,*,五段・ラ行,基本形,まくる
1587 動詞,非自立,*,*,五段・ラ行,基本形,まわる
1588 動詞,非自立,*,*,五段・ラ行,基本形,やがる
1589 動詞,非自立,*,*,五段・ラ行,基本形,やる
1590 動詞,非自立,*,*,五段・ラ行,基本形,切る
1591 動詞,非自立,*,*,五段・ラ行,基本形,参る
1592 動詞,非自立,*,*,五段・ラ行,基本形,取る
1593 動詞,非自立,*,*,五段・ラ行,基本形,回る
1594 動詞,非自立,*,*,五段・ラ行,基本形,終わる
1595 動詞,非自立,*,*,五段・ラ行,未然ウ接続,ある
1596 動詞,非自立,*,*,五段・ラ行,未然ウ接続,おる
1597 動詞,非自立,*,*,五段・ラ行,未然ウ接続,かかる
1598 動詞,非自立,*,*,五段・ラ行,未然ウ接続,きる
1599 動詞,非自立,*,*,五段・ラ行,未然ウ接続,たる
1600 動詞,非自立,*,*,五段・ラ行,未然ウ接続,だる
1601 動詞,非自立,*,*,五段・ラ行,未然ウ接続,とる
1602 動詞,非自立,*,*,五段・ラ行,未然ウ接続,どる
1603 動詞,非自立,*,*,五段・ラ行,未然ウ接続,なる
1604 動詞,非自立,*,*,五段・ラ行,未然ウ接続,はる
1605 動詞,非自立,*,*,五段・ラ行,未然ウ接続,まいる
1606 動詞,非自立,*,*,五段・ラ行,未然ウ接続,まくる
1607 動詞,非自立,*,*,五段・ラ行,未然ウ接続,まわる
1608 動詞,非自立,*,*,五段・ラ行,未然ウ接続,やがる
1609 動詞,非自立,*,*,五段・ラ行,未然ウ接続,やる
1610 動詞,非自立,*,*,五段・ラ行,未然ウ接続,切る
1611 動詞,非自立,*,*,五段・ラ行,未然ウ接続,参る
1612 動詞,非自立,*,*,五段・ラ行,未然ウ接続,取る
1613 動詞,非自立,*,*,五段・ラ行,未然ウ接続,回る
1614 動詞,非自立,*,*,五段・ラ行,未然ウ接続,終わる
1615 動詞,非自立,*,*,五段・ラ行,未然形,ある
1616 動詞,非自立,*,*,五段・ラ行,未然形,おる
1617 動詞,非自立,*,*,五段・ラ行,未然形,かかる
1618 動詞,非自立,*,*,五段・ラ行,未然形,きる
1619 動詞,非自立,*,*,五段・ラ行,未然形,たる
1620 動詞,非自立,*,*,五段・ラ行,未然形,だる
1621 動詞,非自立,*,*,五段・ラ行,未然形,とる
1622 動詞,非自立,*,*,五段・ラ行,未然形,どる
1623 動詞,非自立,*,*,五段・ラ行,未然形,なる
1624 動詞,非自立,*,*,五段・ラ行,未然形,はる
1625 動詞,非自立,*,*,五段・ラ行,未然形,まいる
1626 動詞,非自立,*,*,五段・ラ行,未然形,まくる
1627 動詞,非自立,*,*,五段・ラ行,未然形,まわる
1628 動詞,非自立,*,*,五段・ラ行,未然形,やがる
1629 動詞,非自立,*,*,五段・ラ行,未然形,やる
1630 動詞,非自立,*,*,五段・ラ行,未然形,切る
1631 動詞,非自立,*,*,五段・ラ行,未然形,参る
1632 動詞,非自立,*,*,五段・ラ行,未然形,取る
1633 動詞,非自立,*,*,五段・ラ行,未然形,回る
1634 動詞,非自立,*,*,五段・ラ行,未然形,終わる
1635 動詞,非自立,*,*,五段・ラ行,未然特殊,ある
1636 動詞,非自立,*,*,五段・ラ行,未然特殊,おる
1637 動詞,非自立,*,*,五段・ラ行,未然特殊,かかる
1638 動詞,非自立,*,*,五段・ラ行,未然特殊,きる
1639 動詞,非自立,*,*,五段・ラ行,未然特殊,たる
1640 動詞,非自立,*,*,五段・ラ行,未然特殊,だる
1641 動詞,非自立,*,*,五段・ラ行,未然特殊,とる
1642 動詞,非自立,*,*,五段・ラ行,未然特殊,どる
1643 動詞,非自立,*,*,五段・ラ行,未然特殊,なる
1644 動詞,非自立,*,*,五段・ラ行,未然特殊,はる
1645 動詞,非自立,*,*,五段・ラ行,未然特殊,まいる
1646 動詞,非自立,*,*,五段・ラ行,未然特殊,まくる
1647 動詞,非自立,*,*,五段・ラ行,未然特殊,まわる
1648 動詞,非自立,*,*,五段・ラ行,未然特殊,やがる
1649 動詞,非自立,*,*,五段・ラ行,未然特殊,やる
1650 動詞,非自立,*,*,五段・ラ行,未然特殊,切る
1651 動詞,非自立,*,*,五段・ラ行,未然特殊,参る
1652 動詞,非自立,*,*,五段・ラ行,未然特殊,取る
1653 動詞,非自立,*,*,五段・ラ行,未然特殊,回る
1654 動詞,非自立,*,*,五段・ラ行,未然特殊,終わる
1655 動詞,非自立,*,*,五段・ラ行,連用タ接続,ある
1656 動詞,非自立,*,*,五段・ラ行,連用タ接続,おる
1657 動詞,非自立,*,*,五段・ラ行,連用タ接続,かかる
1658 動詞,非自立,*,*,五段・ラ行,連用タ接続,きる
1659 動詞,非自立,*,*,五段・ラ行,連用タ接続,たる
1660 動詞,非自立,*,*,五段・ラ行,連用タ接続,だる
1661 動詞,非自立,*,*,五段・ラ行,連用タ接続,とる
1662 動詞,非自立,*,*,五段・ラ行,連用タ接続,どる
1663 動詞,非自立,*,*,五段・ラ行,連用タ接続,なる
1664 動詞,非自立,*,*,五段・ラ行,連用タ接続,はる
1665 動詞,非自立,*,*,五段・ラ行,連用タ接続,まいる
1666 動詞,非自立,*,*,五段・ラ行,連用タ接続,まくる
1667 動詞,非自立,*,*,五段・ラ行,連用タ接続,まわる
1668 動詞,非自立,*,*,五段・ラ行,連用タ接続,やがる
1669 動詞,非自立,*,*,五段・ラ行,連用タ接続,やる
1670 動詞,非自立,*,*,五段・ラ行,連用タ接続,切る
1671 動詞,非自立,*,*,五段・ラ行,連用タ接続,参る
1672 動詞,非自立,*,*,五段・ラ行,連用タ接続,取る
1673 動詞,非自立,*,*,五段・ラ行,連用タ接続,回る
1674 動詞,非自立,*,*,五段・ラ行,連用タ接続,終わる
1675 動詞,非自立,*,*,五段・ラ行,連用形,ある
1676 動詞,非自立,*,*,五段・ラ行,連用形,おる
1677 動詞,非自立,*,*,五段・ラ行,連用形,かかる
1678 動詞,非自立,*,*,五段・ラ行,連用形,きる
1679 動詞,非自立,*,*,五段・ラ行,連用形,たる
1680 動詞,非自立,*,*,五段・ラ行,連用形,だる
1681 動詞,非自立,*,*,五段・ラ行,連用形,とる
1682 動詞,非自立,*,*,五段・ラ行,連用形,どる
1683 動詞,非自立,*,*,五段・ラ行,連用形,なる
1684 動詞,非自立,*,*,五段・ラ行,連用形,はる
1685 動詞,非自立,*,*,五段・ラ行,連用形,まいる
1686 動詞,非自立,*,*,五段・ラ行,連用形,まくる
1687 動詞,非自立,*,*,五段・ラ行,連用形,まわる
1688 動詞,非自立,*,*,五段・ラ行,連用形,やがる
1689 動詞,非自立,*,*,五段・ラ行,連用形,やる
1690 動詞,非自立,*,*,五段・ラ行,連用形,ドル
1691 動詞,非自立,*,*,五段・ラ行,連用形,切る
1692 動詞,非自立,*,*,五段・ラ行,連用形,参る
1693 動詞,非自立,*,*,五段・ラ行,連用形,取る
1694 動詞,非自立,*,*,五段・ラ行,連用形,回る
1695 動詞,非自立,*,*,五段・ラ行,連用形,終わる
1696 動詞,非自立,*,*,五段・ラ行特殊,仮定形,いらっしゃる
1697 動詞,非自立,*,*,五段・ラ行特殊,仮定形,くださる
1698 動詞,非自立,*,*,五段・ラ行特殊,仮定形,なさる
1699 動詞,非自立,*,*,五段・ラ行特殊,仮定形,らっしゃる
1700 動詞,非自立,*,*,五段・ラ行特殊,仮定形,下さる
1701 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,いらっしゃる
1702 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,くださる
1703 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,なさる
1704 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,らっしゃる
1705 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,下さる
1706 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,いらっしゃる
1707 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,くださる
1708 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,なさる
1709 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,らっしゃる
1710 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,下さる
1711 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,いらっしゃる
1712 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,くださる
1713 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,なさぁる
1714 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,なさる
1715 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,なさーる
1716 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,なさ～る
1717 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,らっしゃる
1718 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,クダサル
1719 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,ナサル
1720 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,下さる
1721 動詞,非自立,*,*,五段・ラ行特殊,基本形,いらっしゃる
1722 動詞,非自立,*,*,五段・ラ行特殊,基本形,くださる
1723 動詞,非自立,*,*,五段・ラ行特殊,基本形,なさる
1724 動詞,非自立,*,*,五段・ラ行特殊,基本形,らっしゃる
1725 動詞,非自立,*,*,五段・ラ行特殊,基本形,下さる
1726 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,いらっしゃる
1727 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,くださる
1728 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,なさる
1729 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,らっしゃる
1730 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,下さる
1731 動詞,非自立,*,*,五段・ラ行特殊,未然形,いらっしゃる
1732 動詞,非自立,*,*,五段・ラ行特殊,未然形,くださる
1733 動詞,非自立,*,*,五段・ラ行特殊,未然形,なさる
1734 動詞,非自立,*,*,五段・ラ行特殊,未然形,らっしゃる
1735 動詞,非自立,*,*,五段・ラ行特殊,未然形,下さる
1736 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,いらっしゃる
1737 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,くださる
1738 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,なさる
1739 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,らっしゃる
1740 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,下さる
1741 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,いらっしゃる
1742 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,くださる
1743 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,なさる
1744 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,らっしゃる
1745 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,下さる
1746 動詞,非自立,*,*,五段・ラ行特殊,連用形,いらっしゃる
1747 動詞,非自立,*,*,五段・ラ行特殊,連用形,くださる
1748 動詞,非自立,*,*,五段・ラ行特殊,連用形,なさる
1749 動詞,非自立,*,*,五段・ラ行特殊,連用形,らっしゃる
1750 動詞,非自立,*,*,五段・ラ行特殊,連用形,ラッシャル
1751 動詞,非自立,*,*,五段・ラ行特殊,連用形,下さる
1752 動詞,非自立,*,*,五段・ワ行ウ音便,連用タ接続,給う
1753 動詞,非自立,*,*,五段・ワ行ウ音便,連用形,たまう
1754 動詞,非自立,*,*,五段・ワ行促音便,仮定形,あう
1755 動詞,非自立,*,*,五段・ワ行促音便,仮定形,しまう
1756 動詞,非自立,*,*,五段・ワ行促音便,仮定形,じまう
1757 動詞,非自立,*,*,五段・ワ行促音便,仮定形,じゃう
1758 動詞,非自立,*,*,五段・ワ行促音便,仮定形,たまう
1759 動詞,非自立,*,*,五段・ワ行促音便,仮定形,ちまう
1760 動詞,非自立,*,*,五段・ワ行促音便,仮定形,ちゃう
1761 動詞,非自立,*,*,五段・ワ行促音便,仮定形,もらう
1762 動詞,非自立,*,*,五段・ワ行促音便,仮定形,合う
1763 動詞,非自立,*,*,五段・ワ行促音便,仮定形,給う
1764 動詞,非自立,*,*,五段・ワ行促音便,仮定形,願う
1765 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,あう
1766 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,しまう
1767 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,じまう
1768 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,じゃう
1769 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,ちまう
1770 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,ちゃう
1771 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,もらう
1772 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,合う
1773 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,給う
1774 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,願う
1775 動詞,非自立,*,*,五段・ワ行促音便,基本形,あう
1776 動詞,非自立,*,*,五段・ワ行促音便,基本形,しまう
1777 動詞,非自立,*,*,五段・ワ行促音便,基本形,じまう
1778 動詞,非自立,*,*,五段・ワ行促音便,基本形,じゃう
1779 動詞,非自立,*,*,五段・ワ行促音便,基本形,たまう
1780 動詞,非自立,*,*,五段・ワ行促音便,基本形,ちまう
1781 動詞,非自立,*,*,五段・ワ行促音便,基本形,ちゃう
1782 動詞,非自立,*,*,五段・ワ行促音便,基本形,もらう
1783 動詞,非自立,*,*,五段・ワ行促音便,基本形,シマウ
1784 動詞,非自立,*,*,五段・ワ行促音便,基本形,合う
1785 動詞,非自立,*,*,五段・ワ行促音便,基本形,給う
1786 動詞,非自立,*,*,五段・ワ行促音便,基本形,願う
1787 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,あう
1788 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,しまう
1789 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,じまう
1790 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,じゃう
1791 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,たまう
1792 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,ちまう
1793 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,ちゃう
1794 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,もらう
1795 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,合う
1796 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,給う
1797 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,願う
1798 動詞,非自立,*,*,五段・ワ行促音便,未然形,あう
1799 動詞,非自立,*,*,五段・ワ行促音便,未然形,しまう
1800 動詞,非自立,*,*,五段・ワ行促音便,未然形,じまう
1801 動詞,非自立,*,*,五段・ワ行促音便,未然形,じゃう
1802 動詞,非自立,*,*,五段・ワ行促音便,未然形,たまう
1803 動詞,非自立,*,*,五段・ワ行促音便,未然形,ちまう
1804 動詞,非自立,*,*,五段・ワ行促音便,未然形,ちゃう
1805 動詞,非自立,*,*,五段・ワ行促音便,未然形,もらう
1806 動詞,非自立,*,*,五段・ワ行促音便,未然形,合う
1807 動詞,非自立,*,*,五段・ワ行促音便,未然形,給う
1808 動詞,非自立,*,*,五段・ワ行促音便,未然形,願う
1809 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,あう
1810 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,しまう
1811 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,じまう
1812 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,じゃう
1813 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,たまう
1814 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,ちまう
1815 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,ちゃう
1816 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,もらう
1817 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,シマウ
1818 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,合う
1819 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,給う
1820 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,願う
1821 動詞,非自立,*,*,五段・ワ行促音便,連用形,あう
1822 動詞,非自立,*,*,五段・ワ行促音便,連用形,しまう
1823 動詞,非自立,*,*,五段・ワ行促音便,連用形,じまう
1824 動詞,非自立,*,*,五段・ワ行促音便,連用形,じゃう
1825 動詞,非自立,*,*,五段・ワ行促音便,連用形,たまう
1826 動詞,非自立,*,*,五段・ワ行促音便,連用形,ちまう
1827 動詞,非自立,*,*,五段・ワ行促音便,連用形,ちゃう
1828 動詞,非自立,*,*,五段・ワ行促音便,連用形,もらう
1829 動詞,非自立,*,*,五段・ワ行促音便,連用形,合う
1830 動詞,非自立,*,*,五段・ワ行促音便,連用形,給う
1831 動詞,非自立,*,*,五段・ワ行促音便,連用形,願う
1832 動詞,非自立,*,*,四段・ハ行,仮定形,しまふ
1833 動詞,非自立,*,*,四段・ハ行,命令ｅ,しまふ
1834 動詞,非自立,*,*,四段・ハ行,基本形,しまふ
1835 動詞,非自立,*,*,四段・ハ行,未然形,しまふ
1836 動詞,非自立,*,*,四段・ハ行,連用形,しまふ
1837 名詞,サ変接続,*,*,*,*,*
1838 名詞,サ変接続,*,*,*,*,上京
1839 名詞,サ変接続,*,*,*,*,事故
1840 名詞,サ変接続,*,*,*,*,使用
1841 名詞,サ変接続,*,*,*,*,変換
1842 名詞,サ変接続,*,*,*,*,抵抗
1843 名詞,サ変接続,*,*,*,*,試用
1844 名詞,サ変接続,*,*,*,*,話
1845 名詞,サ変接続,*,*,*,*,講座
1846 名詞,ナイ形容詞語幹,*,*,*,*,*
1847 名詞,一般,*,*,*,*,*
1848 名詞,一般,*,*,*,*,あと
1849 名詞,一般,*,*,*,*,こ
1850 名詞,一般,*,*,*,*,はなし
1851 名詞,一般,*,*,*,*,ほん
1852 名詞,一般,*,*,*,*,上
1853 名詞,一般,*,*,*,*,下
1854 名詞,一般,*,*,*,*,仕様
1855 名詞,一般,*,*,*,*,他
1856 名詞,一般,*,*,*,*,件
1857 名詞,一般,*,*,*,*,何Xか
1858 名詞,一般,*,*,*,*,例
1859 名詞,一般,*,*,*,*,北
1860 名詞,一般,*,*,*,*,危機
1861 名詞,一般,*,*,*,*,口座
1862 名詞,一般,*,*,*,*,地震
1863 名詞,一般,*,*,*,*,声
1864 名詞,一般,*,*,*,*,女史
1865 名詞,一般,*,*,*,*,女子
1866 名詞,一般,*,*,*,*,子
1867 名詞,一般,*,*,*,*,家
1868 名詞,一般,*,*,*,*,家庭
1869 名詞,一般,*,*,*,*,年
1870 名詞,一般,*,*,*,*,店
1871 名詞,一般,*,*,*,*,得
1872 名詞,一般,*,*,*,*,手
1873 名詞,一般,*,*,*,*,月
1874 名詞,一般,*,*,*,*,期間
1875 名詞,一般,*,*,*,*,木
1876 名詞,一般,*,*,*,*,本
1877 名詞,一般,*,*,*,*,機会
1878 名詞,一般,*,*,*,*,機器
1879 名詞,一般,*,*,*,*,機械
1880 名詞,一般,*,*,*,*,機関
1881 名詞,一般,*,*,*,*,気
1882 名詞,一般,*,*,*,*,無
1883 名詞,一般,*,*,*,*,状況
1884 名詞,一般,*,*,*,*,目
1885 名詞,一般,*,*,*,*,自己
1886 名詞,一般,*,*,*,*,自身
1887 名詞,一般,*,*,*,*,色
1888 名詞,一般,*,*,*,*,課程
1889 名詞,一般,*,*,*,*,過程
1890 名詞,一般,*,*,*,*,間
1891 名詞,一般,*,*,*,*,音
1892 名詞,一般,*,*,*,*,顔
1893 名詞,一般,*,*,*,*,駅
1894 名詞,一般,*,*,*,*,魚
1895 名詞,代名詞,一般,*,*,*,*
1896 名詞,代名詞,一般,*,*,*,わたし
1897 名詞,代名詞,一般,*,*,*,何Xか
1898 名詞,代名詞,一般,*,*,*,私
1899 名詞,代名詞,副詞可能,*,*,*,*
1900 名詞,代名詞,副詞可能,時間,*,*,*
1901 名詞,代名詞,場所,*,*,*,*
1902 名詞,代名詞,対象,*,*,*,*
1903 名詞,代名詞,対象・場所,*,*,*,*
1904 名詞,代名詞,縮約,*,*,*,*
1905 名詞,副詞可能,*,*,*,*,*
1906 名詞,副詞可能,*,*,*,*,いま
1907 名詞,副詞可能,*,*,*,*,すべて
1908 名詞,副詞可能,*,*,*,*,今
1909 名詞,副詞可能,*,*,*,*,今日
1910 名詞,副詞可能,*,*,*,*,前
1911 名詞,副詞可能,*,*,*,*,場合
1912 名詞,副詞可能,*,*,*,*,時間
1913 名詞,副詞可能,*,*,*,*,現在
1914 名詞,副詞可能,*,*,*,*,結果
1915 名詞,動詞非自立的,*,*,*,*,*
1916 名詞,固有名詞,一般,*,*,*,*
1917 名詞,固有名詞,人名,一般,*,*,*
1918 名詞,固有名詞,人名,名,*,*,*
1919 名詞,固有名詞,人名,姓,*,*,*
1920 名詞,固有名詞,地域,一般,*,*,*
1921 名詞,固有名詞,地域,一般,*,*,府名
1922 名詞,固有名詞,地域,一般,*,*,県名
1923 名詞,固有名詞,地域,一般,*,*,都名
1924 名詞,固有名詞,地域,国,*,*,*
1925 名詞,固有名詞,組織,*,*,*,*
1926 名詞,引用文字列,*,*,*,*,*
1927 名詞,形容動詞語幹,*,*,*,*,*
1928 名詞,形容動詞語幹,*,*,*,*,こんな
1929 名詞,形容動詞語幹,*,*,*,*,そんな
1930 名詞,形容動詞語幹,*,*,*,*,どんな
1931 名詞,形容動詞語幹,*,*,*,*,同じ
1932 名詞,接尾,サ変接続,*,*,*,仕舞い
1933 名詞,接尾,サ変接続,*,*,*,会
1934 名詞,接尾,サ変接続,*,*,*,入り
1935 名詞,接尾,サ変接続,*,*,*,分け
1936 名詞,接尾,サ変接続,*,*,*,勝
1937 名詞,接尾,サ変接続,*,*,*,化
1938 名詞,接尾,サ変接続,*,*,*,干し
1939 名詞,接尾,サ変接続,*,*,*,式
1940 名詞,接尾,サ変接続,*,*,*,損
1941 名詞,接尾,サ変接続,*,*,*,死
1942 名詞,接尾,サ変接続,*,*,*,視
1943 名詞,接尾,サ変接続,*,*,*,話
1944 名詞,接尾,一般,*,*,*,*
1945 名詞,接尾,一般,*,*,*,よう
1946 名詞,接尾,一般,*,*,*,事
1947 名詞,接尾,一般,*,*,*,人
1948 名詞,接尾,一般,*,*,*,休
1949 名詞,接尾,一般,*,*,*,内
1950 名詞,接尾,一般,*,*,*,刑
1951 名詞,接尾,一般,*,*,*,初
1952 名詞,接尾,一般,*,*,*,制
1953 名詞,接尾,一般,*,*,*,勝
1954 名詞,接尾,一般,*,*,*,名
1955 名詞,接尾,一般,*,*,*,器
1956 名詞,接尾,一般,*,*,*,型
1957 名詞,接尾,一般,*,*,*,外
1958 名詞,接尾,一般,*,*,*,小
1959 名詞,接尾,一般,*,*,*,展
1960 名詞,接尾,一般,*,*,*,店
1961 名詞,接尾,一般,*,*,*,式
1962 名詞,接尾,一般,*,*,*,引き
1963 名詞,接尾,一般,*,*,*,形
1964 名詞,接尾,一般,*,*,*,性
1965 名詞,接尾,一般,*,*,*,書
1966 名詞,接尾,一般,*,*,*,期
1967 名詞,接尾,一般,*,*,*,機
1968 名詞,接尾,一般,*,*,*,点
1969 名詞,接尾,一般,*,*,*,無し
1970 名詞,接尾,一般,*,*,*,球
1971 名詞,接尾,一般,*,*,*,産
1972 名詞,接尾,一般,*,*,*,用
1973 名詞,接尾,一般,*,*,*,症
1974 名詞,接尾,一般,*,*,*,痛
1975 名詞,接尾,一般,*,*,*,発
1976 名詞,接尾,一般,*,*,*,目
1977 名詞,接尾,一般,*,*,*,省
1978 名詞,接尾,一般,*,*,*,系
1979 名詞,接尾,一般,*,*,*,級
1980 名詞,接尾,一般,*,*,*,者
1981 名詞,接尾,一般,*,*,*,臭
1982 名詞,接尾,一般,*,*,*,葉
1983 名詞,接尾,一般,*,*,*,製
1984 名詞,接尾,一般,*,*,*,計
1985 名詞,接尾,一般,*,*,*,記
1986 名詞,接尾,一般,*,*,*,証
1987 名詞,接尾,一般,*,*,*,買
1988 名詞,接尾,一般,*,*,*,買い
1989 名詞,接尾,一般,*,*,*,賞
1990 名詞,接尾,一般,*,*,*,週
1991 名詞,接尾,一般,*,*,*,階
1992 名詞,接尾,一般,*,*,*,集
1993 名詞,接尾,人名,*,*,*,*
1994 名詞,接尾,副詞可能,*,*,*,*
1995 名詞,接尾,副詞可能,*,*,*,上
1996 名詞,接尾,副詞可能,*,*,*,中
1997 名詞,接尾,副詞可能,*,*,*,分
1998 名詞,接尾,副詞可能,*,*,*,前
1999 名詞,接尾,副詞可能,*,*,*,後
2000 名詞,接尾,副詞可能,*,*,*,時
2001 名詞,接尾,副詞可能,*,*,*,末
2002 名詞,接尾,助動詞語幹,*,*,*,そ
2003 名詞,接尾,助動詞語幹,*,*,*,そう
2004 名詞,接尾,助数詞,*,*,*,*
2005 名詞,接尾,助数詞,*,*,*,つ
2006 名詞,接尾,助数詞,*,*,*,周
2007 名詞,接尾,助数詞,*,*,*,回
2008 名詞,接尾,助数詞,*,*,*,時
2009 名詞,接尾,助数詞,*,*,*,月
2010 名詞,接尾,助数詞,*,*,*,次
2011 名詞,接尾,助数詞,*,*,*,階
2012 名詞,接尾,地域,*,*,*,*
2013 名詞,接尾,地域,*,*,*,区
2014 名詞,接尾,地域,*,*,*,市
2015 名詞,接尾,地域,*,*,*,府
2016 名詞,接尾,地域,*,*,*,村
2017 名詞,接尾,地域,*,*,*,町
2018 名詞,接尾,地域,*,*,*,県
2019 名詞,接尾,地域,*,*,*,郡
2020 名詞,接尾,地域,*,*,*,駅
2021 名詞,接尾,形容動詞語幹,*,*,*,*
2022 名詞,接尾,形容動詞語幹,*,*,*,がち
2023 名詞,接尾,形容動詞語幹,*,*,*,好き
2024 名詞,接尾,形容動詞語幹,*,*,*,用
2025 名詞,接尾,形容動詞語幹,*,*,*,的
2026 名詞,接尾,特殊,*,*,*,さ
2027 名詞,接尾,特殊,*,*,*,たて
2028 名詞,接尾,特殊,*,*,*,っぷり
2029 名詞,接尾,特殊,*,*,*,ぶり
2030 名詞,接尾,特殊,*,*,*,み
2031 名詞,接尾,特殊,*,*,*,カタ
2032 名詞,接尾,特殊,*,*,*,方
2033 名詞,接尾可能,人名,*,*,*,*
2034 名詞,接尾可能,人名,*,*,*,女史
2035 名詞,接続詞的,*,*,*,*,*
2036 名詞,数,*,*,*,*,*
2037 名詞,数,アラビア数字,*,*,*,*
2038 名詞,数,区切り文字,*,*,*,*
2039 名詞,数,漢数字,*,*,*,*
2040 名詞,数,漢数字,*,*,*,万
2041 名詞,数,漢数字,*,*,*,京
2042 名詞,数,漢数字,*,*,*,億
2043 名詞,数,漢数字,*,*,*,兆
2044 名詞,数,漢数字,*,*,*,十
2045 名詞,数,漢数字,*,*,*,千
2046 名詞,数,漢数字,*,*,*,垓
2047 名詞,数,漢数字,*,*,*,澗
2048 名詞,数,漢数字,*,*,*,百
2049 名詞,特殊,助動詞語幹,*,*,*,*
2050 名詞,非自立,一般,*,*,*,あまり
2051 名詞,非自立,一般,*,*,*,うえ
2052 名詞,非自立,一般,*,*,*,うち
2053 名詞,非自立,一般,*,*,*,かい
2054 名詞,非自立,一般,*,*,*,かけ
2055 名詞,非自立,一般,*,*,*,かた
2056 名詞,非自立,一般,*,*,*,がい
2057 名詞,非自立,一般,*,*,*,きらい
2058 名詞,非自立,一般,*,*,*,くせ
2059 名詞,非自立,一般,*,*,*,こと
2060 名詞,非自立,一般,*,*,*,こなし
2061 名詞,非自立,一般,*,*,*,さし
2062 名詞,非自立,一般,*,*,*,さま
2063 名詞,非自立,一般,*,*,*,さら
2064 名詞,非自立,一般,*,*,*,すえ
2065 名詞,非自立,一般,*,*,*,すべ
2066 名詞,非自立,一般,*,*,*,せい
2067 名詞,非自立,一般,*,*,*,たか
2068 名詞,非自立,一般,*,*,*,たぐい
2069 名詞,非自立,一般,*,*,*,ため
2070 名詞,非自立,一般,*,*,*,つもり
2071 名詞,非自立,一般,*,*,*,とき
2072 名詞,非自立,一般,*,*,*,どころ
2073 名詞,非自立,一般,*,*,*,の
2074 名詞,非自立,一般,*,*,*,のん
2075 名詞,非自立,一般,*,*,*,はず
2076 名詞,非自立,一般,*,*,*,はずみ
2077 名詞,非自立,一般,*,*,*,ふし
2078 名詞,非自立,一般,*,*,*,ふり
2079 名詞,非自立,一般,*,*,*,へん
2080 名詞,非自立,一般,*,*,*,ほう
2081 名詞,非自立,一般,*,*,*,ほど
2082 名詞,非自立,一般,*,*,*,もと
2083 名詞,非自立,一般,*,*,*,もの
2084 名詞,非自立,一般,*,*,*,もん
2085 名詞,非自立,一般,*,*,*,やつ
2086 名詞,非自立,一般,*,*,*,わけ
2087 名詞,非自立,一般,*,*,*,ん
2088 名詞,非自立,一般,*,*,*,コト
2089 名詞,非自立,一般,*,*,*,ツモリ
2090 名詞,非自立,一般,*,*,*,ドコロ
2091 名詞,非自立,一般,*,*,*,フシ
2092 名詞,非自立,一般,*,*,*,ホ
2093 名詞,非自立,一般,*,*,*,モノ
2094 名詞,非自立,一般,*,*,*,ン
2095 名詞,非自立,一般,*,*,*,下
2096 名詞,非自立,一般,*,*,*,事
2097 名詞,非自立,一般,*,*,*,以北
2098 名詞,非自立,一般,*,*,*,以南
2099 名詞,非自立,一般,*,*,*,作
2100 名詞,非自立,一般,*,*,*,側
2101 名詞,非自立,一般,*,*,*,割
2102 名詞,非自立,一般,*,*,*,半
2103 名詞,非自立,一般,*,*,*,厨
2104 名詞,非自立,一般,*,*,*,場
2105 名詞,非自立,一般,*,*,*,奴
2106 名詞,非自立,一般,*,*,*,折
2107 名詞,非自立,一般,*,*,*,故
2108 名詞,非自立,一般,*,*,*,方
2109 名詞,非自立,一般,*,*,*,日
2110 名詞,非自立,一般,*,*,*,旨
2111 名詞,非自立,一般,*,*,*,時
2112 名詞,非自立,一般,*,*,*,機
2113 名詞,非自立,一般,*,*,*,気
2114 名詞,非自立,一般,*,*,*,点
2115 名詞,非自立,一般,*,*,*,物
2116 名詞,非自立,一般,*,*,*,生み
2117 名詞,非自立,一般,*,*,*,目
2118 名詞,非自立,一般,*,*,*,程
2119 名詞,非自立,一般,*,*,*,種
2120 名詞,非自立,一般,*,*,*,筈
2121 名詞,非自立,一般,*,*,*,者
2122 名詞,非自立,一般,*,*,*,訳
2123 名詞,非自立,副詞可能,*,*,*,あまり
2124 名詞,非自立,副詞可能,*,*,*,うえ
2125 名詞,非自立,副詞可能,*,*,*,うち
2126 名詞,非自立,副詞可能,*,*,*,かぎり
2127 名詞,非自立,副詞可能,*,*,*,かた
2128 名詞,非自立,副詞可能,*,*,*,きり
2129 名詞,非自立,副詞可能,*,*,*,ころ
2130 名詞,非自立,副詞可能,*,*,*,ごと
2131 名詞,非自立,副詞可能,*,*,*,さなか
2132 名詞,非自立,副詞可能,*,*,*,たび
2133 名詞,非自立,副詞可能,*,*,*,ため
2134 名詞,非自立,副詞可能,*,*,*,っきり
2135 名詞,非自立,副詞可能,*,*,*,ついで
2136 名詞,非自立,副詞可能,*,*,*,つど
2137 名詞,非自立,副詞可能,*,*,*,とおり
2138 名詞,非自立,副詞可能,*,*,*,とき
2139 名詞,非自立,副詞可能,*,*,*,ところ
2140 名詞,非自立,副詞可能,*,*,*,とたん
2141 名詞,非自立,副詞可能,*,*,*,なか
2142 名詞,非自立,副詞可能,*,*,*,のち
2143 名詞,非自立,副詞可能,*,*,*,はじめ
2144 名詞,非自立,副詞可能,*,*,*,はず
2145 名詞,非自立,副詞可能,*,*,*,ほど
2146 名詞,非自立,副詞可能,*,*,*,まま
2147 名詞,非自立,副詞可能,*,*,*,まんま
2148 名詞,非自立,副詞可能,*,*,*,ゆえ
2149 名詞,非自立,副詞可能,*,*,*,トコロ
2150 名詞,非自立,副詞可能,*,*,*,マンマ
2151 名詞,非自立,副詞可能,*,*,*,一方
2152 名詞,非自立,副詞可能,*,*,*,中
2153 名詞,非自立,副詞可能,*,*,*,他
2154 名詞,非自立,副詞可能,*,*,*,以上
2155 名詞,非自立,副詞可能,*,*,*,以内
2156 名詞,非自立,副詞可能,*,*,*,以外
2157 名詞,非自立,副詞可能,*,*,*,以後
2158 名詞,非自立,副詞可能,*,*,*,以降
2159 名詞,非自立,副詞可能,*,*,*,内
2160 名詞,非自立,副詞可能,*,*,*,初め
2161 名詞,非自立,副詞可能,*,*,*,夕
2162 名詞,非自立,副詞可能,*,*,*,外
2163 名詞,非自立,副詞可能,*,*,*,家
2164 名詞,非自立,副詞可能,*,*,*,度
2165 名詞,非自立,副詞可能,*,*,*,後
2166 名詞,非自立,副詞可能,*,*,*,後半
2167 名詞,非自立,副詞可能,*,*,*,所
2168 名詞,非自立,副詞可能,*,*,*,折
2169 名詞,非自立,副詞可能,*,*,*,故
2170 名詞,非自立,副詞可能,*,*,*,日
2171 名詞,非自立,副詞可能,*,*,*,時
2172 名詞,非自立,副詞可能,*,*,*,未満
2173 名詞,非自立,副詞可能,*,*,*,末
2174 名詞,非自立,副詞可能,*,*,*,毎
2175 名詞,非自立,副詞可能,*,*,*,為
2176 名詞,非自立,副詞可能,*,*,*,矢先
2177 名詞,非自立,副詞可能,*,*,*,自身
2178 名詞,非自立,副詞可能,*,*,*,途端
2179 名詞,非自立,副詞可能,*,*,*,都度
2180 名詞,非自立,副詞可能,*,*,*,限り
2181 名詞,非自立,副詞可能,*,*,*,際
2182 名詞,非自立,副詞可能,*,*,*,頃
2183 名詞,非自立,助動詞語幹,*,*,*,やう
2184 名詞,非自立,助動詞語幹,*,*,*,よ
2185 名詞,非自立,助動詞語幹,*,*,*,よう
2186 名詞,非自立,助動詞語幹,*,*,*,様
2187 名詞,非自立,形容動詞語幹,*,*,*,ふう
2188 名詞,非自立,形容動詞語幹,*,*,*,みたい
2189 形容詞,接尾,*,*,*,文語基本形,*
2190 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,くさい
2191 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,っぽい
2192 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,ぽい
2193 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,太い
2194 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,強い
2195 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,早い
2196 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,深い
2197 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,臭い
2198 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,辛い
2199 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,速い
2200 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,遠い
2201 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,高い
2202 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,黒い
2203 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,くさい
2204 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,っぽい
2205 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,ぽい
2206 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,太い
2207 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,強い
2208 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,早い
2209 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,深い
2210 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,臭い
2211 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,辛い
2212 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,速い
2213 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,遠い
2214 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,高い
2215 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,黒い
2216 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,くさい
2217 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,っぽい
2218 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,ぽい
2219 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,太い
2220 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,強い
2221 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,早い
2222 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,深い
2223 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,臭い
2224 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,辛い
2225 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,速い
2226 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,遠い
2227 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,高い
2228 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,黒い
2229 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,くさい
2230 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,っぽい
2231 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,ぽい
2232 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,太い
2233 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,強い
2234 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,早い
2235 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,深い
2236 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,臭い
2237 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,辛い
2238 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,速い
2239 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,遠い
2240 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,高い
2241 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,黒い
2242 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,くさい
2243 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,っぽい
2244 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,ぽい
2245 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,ポイ
2246 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,太い
2247 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,強い
2248 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,早い
2249 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,深い
2250 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,臭い
2251 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,辛い
2252 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,速い
2253 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,遠い
2254 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,高い
2255 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,黒い
2256 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,くさい
2257 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,っぽい
2258 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,太い
2259 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,強い
2260 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,早い
2261 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,深い
2262 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,臭い
2263 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,辛い
2264 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,速い
2265 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,遠い
2266 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,高い
2267 形容詞,接尾,*,*,形容詞・アウオ段,口語基本形,黒い
2268 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,くさい
2269 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,っぽい
2270 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,ぽい
2271 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,太い
2272 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,強い
2273 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,早い
2274 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,深い
2275 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,臭い
2276 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,辛い
2277 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,速い
2278 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,遠い
2279 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,高い
2280 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,黒い
2281 形容詞,接尾,*,*,形容詞・アウオ段,基本形,くさい
2282 形容詞,接尾,*,*,形容詞・アウオ段,基本形,っぽい
2283 形容詞,接尾,*,*,形容詞・アウオ段,基本形,ぽい
2284 形容詞,接尾,*,*,形容詞・アウオ段,基本形,太い
2285 形容詞,接尾,*,*,形容詞・アウオ段,基本形,強い
2286 形容詞,接尾,*,*,形容詞・アウオ段,基本形,早い
2287 形容詞,接尾,*,*,形容詞・アウオ段,基本形,深い
2288 形容詞,接尾,*,*,形容詞・アウオ段,基本形,臭い
2289 形容詞,接尾,*,*,形容詞・アウオ段,基本形,辛い
2290 形容詞,接尾,*,*,形容詞・アウオ段,基本形,速い
2291 形容詞,接尾,*,*,形容詞・アウオ段,基本形,遠い
2292 形容詞,接尾,*,*,形容詞・アウオ段,基本形,高い
2293 形容詞,接尾,*,*,形容詞・アウオ段,基本形,黒い
2294 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,くさい
2295 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,っぽい
2296 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,ぽい
2297 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,太い
2298 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,強い
2299 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,早い
2300 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,深い
2301 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,臭い
2302 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,辛い
2303 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,速い
2304 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,遠い
2305 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,高い
2306 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,黒い
2307 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,くさい
2308 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,っぽい
2309 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,ぽい
2310 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,太い
2311 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,強い
2312 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,早い
2313 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,深い
2314 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,臭い
2315 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,辛い
2316 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,速い
2317 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,遠い
2318 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,高い
2319 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,黒い
2320 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,くさい
2321 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,っぽい
2322 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,ぽい
2323 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,ポイ
2324 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,太い
2325 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,強い
2326 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,早い
2327 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,深い
2328 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,臭い
2329 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,辛い
2330 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,速い
2331 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,遠い
2332 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,高い
2333 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,黒い
2334 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,くさい
2335 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,っぽい
2336 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,ぽい
2337 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,太い
2338 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,強い
2339 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,早い
2340 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,深い
2341 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,臭い
2342 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,辛い
2343 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,速い
2344 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,遠い
2345 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,高い
2346 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,黒い
2347 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,くさい
2348 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,っぽい
2349 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,ぽい
2350 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,太い
2351 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,強い
2352 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,早い
2353 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,深い
2354 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,臭い
2355 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,辛い
2356 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,速い
2357 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,遠い
2358 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,高い
2359 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,黒い
2360 形容詞,接尾,*,*,形容詞・イ段,ガル接続,たらしい
2361 形容詞,接尾,*,*,形容詞・イ段,ガル接続,ったらしい
2362 形容詞,接尾,*,*,形容詞・イ段,仮定形,たらしい
2363 形容詞,接尾,*,*,形容詞・イ段,仮定形,ったらしい
2364 形容詞,接尾,*,*,形容詞・イ段,仮定縮約１,たらしい
2365 形容詞,接尾,*,*,形容詞・イ段,仮定縮約１,ったらしい
2366 形容詞,接尾,*,*,形容詞・イ段,仮定縮約２,たらしい
2367 形容詞,接尾,*,*,形容詞・イ段,仮定縮約２,ったらしい
2368 形容詞,接尾,*,*,形容詞・イ段,体言接続,たらしい
2369 形容詞,接尾,*,*,形容詞・イ段,体言接続,ったらしい
2370 形容詞,接尾,*,*,形容詞・イ段,命令ｅ,たらしい
2371 形容詞,接尾,*,*,形容詞・イ段,命令ｅ,ったらしい
2372 形容詞,接尾,*,*,形容詞・イ段,基本形,たらしい
2373 形容詞,接尾,*,*,形容詞・イ段,基本形,ったらしい
2374 形容詞,接尾,*,*,形容詞・イ段,未然ウ接続,たらしい
2375 形容詞,接尾,*,*,形容詞・イ段,未然ウ接続,ったらしい
2376 形容詞,接尾,*,*,形容詞・イ段,未然ヌ接続,たらしい
2377 形容詞,接尾,*,*,形容詞・イ段,未然ヌ接続,ったらしい
2378 形容詞,接尾,*,*,形容詞・イ段,連用ゴザイ接続,たらしい
2379 形容詞,接尾,*,*,形容詞・イ段,連用ゴザイ接続,ったらしい
2380 形容詞,接尾,*,*,形容詞・イ段,連用タ接続,たらしい
2381 形容詞,接尾,*,*,形容詞・イ段,連用タ接続,ったらしい
2382 形容詞,接尾,*,*,形容詞・イ段,連用テ接続,たらしい
2383 形容詞,接尾,*,*,形容詞・イ段,連用テ接続,ったらしい
2384 形容詞,自立,*,*,*,文語基本形,*
2385 形容詞,自立,*,*,不変化型,基本形,*
2386 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,*
2387 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,ない
2388 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,よい
2389 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,無い
2390 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,良い
2391 形容詞,自立,*,*,形容詞・アウオ段,仮定形,*
2392 形容詞,自立,*,*,形容詞・アウオ段,仮定形,ない
2393 形容詞,自立,*,*,形容詞・アウオ段,仮定形,よい
2394 形容詞,自立,*,*,形容詞・アウオ段,仮定形,無い
2395 形容詞,自立,*,*,形容詞・アウオ段,仮定形,良い
2396 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,*
2397 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,ない
2398 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,よい
2399 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,無い
2400 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,良い
2401 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,*
2402 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,ない
2403 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,よい
2404 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,無い
2405 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,良い
2406 形容詞,自立,*,*,形容詞・アウオ段,体言接続,*
2407 形容詞,自立,*,*,形容詞・アウオ段,体言接続,ない
2408 形容詞,自立,*,*,形容詞・アウオ段,体言接続,よい
2409 形容詞,自立,*,*,形容詞・アウオ段,体言接続,無い
2410 形容詞,自立,*,*,形容詞・アウオ段,体言接続,良い
2411 形容詞,自立,*,*,形容詞・アウオ段,口語基本形,*
2412 形容詞,自立,*,*,形容詞・アウオ段,口語基本形-促音便,*
2413 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,*
2414 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,ない
2415 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,よい
2416 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,無い
2417 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,良い
2418 形容詞,自立,*,*,形容詞・アウオ段,基本形,*
2419 形容詞,自立,*,*,形容詞・アウオ段,基本形,ない
2420 形容詞,自立,*,*,形容詞・アウオ段,基本形,よい
2421 形容詞,自立,*,*,形容詞・アウオ段,基本形,無い
2422 形容詞,自立,*,*,形容詞・アウオ段,基本形,良い
2423 形容詞,自立,*,*,形容詞・アウオ段,文語基本形,ない
2424 形容詞,自立,*,*,形容詞・アウオ段,文語基本形,よい
2425 形容詞,自立,*,*,形容詞・アウオ段,文語基本形,無い
2426 形容詞,自立,*,*,形容詞・アウオ段,文語基本形,良い
2427 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,*
2428 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,ない
2429 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,よい
2430 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,無い
2431 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,良い
2432 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,*
2433 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,ない
2434 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,よい
2435 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,無い
2436 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,良い
2437 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,*
2438 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,ない
2439 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,よい
2440 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,無い
2441 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,良い
2442 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,*
2443 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,ない
2444 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,よい
2445 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,無い
2446 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,良い
2447 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,*
2448 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,ない
2449 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,よい
2450 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,無い
2451 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,良い
2452 形容詞,自立,*,*,形容詞・イイ,基本形,いい
2453 形容詞,自立,*,*,形容詞・イイ,基本形-促音便,いい
2454 形容詞,自立,*,*,形容詞・イ段,ガル接続,*
2455 形容詞,自立,*,*,形容詞・イ段,仮定形,*
2456 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,*
2457 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,*
2458 形容詞,自立,*,*,形容詞・イ段,体言接続,*
2459 形容詞,自立,*,*,形容詞・イ段,命令ｅ,*
2460 形容詞,自立,*,*,形容詞・イ段,基本形,*
2461 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,*
2462 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,*
2463 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,*
2464 形容詞,自立,*,*,形容詞・イ段,連用タ接続,*
2465 形容詞,自立,*,*,形容詞・イ段,連用テ接続,*
2466 形容詞,非自立,*,*,*,文語基本形,*
2467 形容詞,非自立,*,*,不変化型,基本形,いい
2468 形容詞,非自立,*,*,不変化型,基本形,イイ
2469 形容詞,非自立,*,*,不変化型,基本形-促音便,いい
2470 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,がたい
2471 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,づらい
2472 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,にくい
2473 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,やすい
2474 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,よい
2475 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,良い
2476 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,難い
2477 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,がたい
2478 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,づらい
2479 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,にくい
2480 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,やすい
2481 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,よい
2482 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,良い
2483 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,難い
2484 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,がたい
2485 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,づらい
2486 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,にくい
2487 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,やすい
2488 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,よい
2489 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,良い
2490 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,難い
2491 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,がたい
2492 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,づらい
2493 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,にくい
2494 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,やすい
2495 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,よい
2496 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,良い
2497 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,難い
2498 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,がたい
2499 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,づらい
2500 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,にくい
2501 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,やすい
2502 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,よい
2503 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,良い
2504 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,難い
2505 形容詞,非自立,*,*,形容詞・アウオ段,口語基本形,がたい
2506 形容詞,非自立,*,*,形容詞・アウオ段,口語基本形,づらい
2507 形容詞,非自立,*,*,形容詞・アウオ段,口語基本形,にくい
2508 形容詞,非自立,*,*,形容詞・アウオ段,口語基本形,やすい
2509 形容詞,非自立,*,*,形容詞・アウオ段,口語基本形,難い
2510 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,がたい
2511 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,づらい
2512 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,にくい
2513 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,やすい
2514 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,よい
2515 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,良い
2516 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,難い
2517 形容詞,非自立,*,*,形容詞・アウオ段,基本形,がたい
2518 形容詞,非自立,*,*,形容詞・アウオ段,基本形,づらい
2519 形容詞,非自立,*,*,形容詞・アウオ段,基本形,にくい
2520 形容詞,非自立,*,*,形容詞・アウオ段,基本形,やすい
2521 形容詞,非自立,*,*,形容詞・アウオ段,基本形,よい
2522 形容詞,非自立,*,*,形容詞・アウオ段,基本形,ヅライ
2523 形容詞,非自立,*,*,形容詞・アウオ段,基本形,良い
2524 形容詞,非自立,*,*,形容詞・アウオ段,基本形,難い
2525 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,がたい
2526 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,づらい
2527 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,にくい
2528 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,やすい
2529 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,よい
2530 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,良い
2531 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,難い
2532 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,がたい
2533 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,づらい
2534 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,にくい
2535 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,やすい
2536 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,よい
2537 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,良い
2538 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,難い
2539 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,がたい
2540 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,づらい
2541 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,にくい
2542 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,やすい
2543 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,よい
2544 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,良い
2545 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,難い
2546 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,がたい
2547 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,づらい
2548 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,にくい
2549 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,やすい
2550 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,よい
2551 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,良い
2552 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,難い
2553 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,がたい
2554 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,づらい
2555 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,にくい
2556 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,やすい
2557 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,よい
2558 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,良い
2559 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,難い
2560 形容詞,非自立,*,*,形容詞・イ段,ガル接続,ほしい
2561 形容詞,非自立,*,*,形容詞・イ段,ガル接続,欲しい
2562 形容詞,非自立,*,*,形容詞・イ段,仮定形,ほしい
2563 形容詞,非自立,*,*,形容詞・イ段,仮定形,欲しい
2564 形容詞,非自立,*,*,形容詞・イ段,仮定縮約１,ほしい
2565 形容詞,非自立,*,*,形容詞・イ段,仮定縮約１,欲しい
2566 形容詞,非自立,*,*,形容詞・イ段,仮定縮約２,ほしい
2567 形容詞,非自立,*,*,形容詞・イ段,仮定縮約２,欲しい
2568 形容詞,非自立,*,*,形容詞・イ段,体言接続,ほしい
2569 形容詞,非自立,*,*,形容詞・イ段,体言接続,欲しい
2570 形容詞,非自立,*,*,形容詞・イ段,命令ｅ,ほしい
2571 形容詞,非自立,*,*,形容詞・イ段,命令ｅ,欲しい
2572 形容詞,非自立,*,*,形容詞・イ段,基本形,ほしい
2573 形容詞,非自立,*,*,形容詞・イ段,基本形,欲しい
2574 形容詞,非自立,*,*,形容詞・イ段,未然ウ接続,ほしい
2575 形容詞,非自立,*,*,形容詞・イ段,未然ウ接続,欲しい
2576 形容詞,非自立,*,*,形容詞・イ段,未然ヌ接続,ほしい
2577 形容詞,非自立,*,*,形容詞・イ段,未然ヌ接続,欲しい
2578 形容詞,非自立,*,*,形容詞・イ段,連用ゴザイ接続,ほしい
2579 形容詞,非自立,*,*,形容詞・イ段,連用ゴザイ接続,欲しい
2580 形容詞,非自立,*,*,形容詞・イ段,連用タ接続,ほしい
2581 形容詞,非自立,*,*,形容詞・イ段,連用タ接続,欲しい
2582 形容詞,非自立,*,*,形容詞・イ段,連用テ接続,ほしい
2583 形容詞,非自立,*,*,形容詞・イ段,連用テ接続,欲しい
2584 感動詞,*,*,*,*,*,*
2585 感動詞,*,*,*,*,*,は
2586 接続詞,*,*,*,*,*,*
2587 接続詞,*,*,*,*,*,が
2588 接続詞,*,*,*,*,*,で
2589 接頭詞,動詞接続,*,*,*,*,*
2590 接頭詞,動詞接続,*,*,*,*,お
2591 接頭詞,動詞接続,*,*,*,*,大
2592 接頭詞,動詞接続,*,*,*,*,御
2593 接頭詞,名詞接続,*,*,*,*,*
2594 接頭詞,名詞接続,*,*,*,*,お
2595 接頭詞,名詞接続,*,*,*,*,ご
2596 接頭詞,名詞接続,*,*,*,*,み
2597 接頭詞,名詞接続,*,*,*,*,もと
2598 接頭詞,名詞接続,*,*,*,*,不
2599 接頭詞,名詞接続,*,*,*,*,代
2600 接頭詞,名詞接続,*,*,*,*,低
2601 接頭詞,名詞接続,*,*,*,*,元
2602 接頭詞,名詞接続,*,*,*,*,全
2603 接頭詞,名詞接続,*,*,*,*,再
2604 接頭詞,名詞接続,*,*,*,*,初
2605 接頭詞,名詞接続,*,*,*,*,前
2606 接頭詞,名詞接続,*,*,*,*,各
2607 接頭詞,名詞接続,*,*,*,*,同
2608 接頭詞,名詞接続,*,*,*,*,大
2609 接頭詞,名詞接続,*,*,*,*,小
2610 接頭詞,名詞接続,*,*,*,*,当
2611 接頭詞,名詞接続,*,*,*,*,御
2612 接頭詞,名詞接続,*,*,*,*,新
2613 接頭詞,名詞接続,*,*,*,*,最
2614 接頭詞,名詞接続,*,*,*,*,未
2615 接頭詞,名詞接続,*,*,*,*,本
2616 接頭詞,名詞接続,*,*,*,*,次
2617 接頭詞,名詞接続,*,*,*,*,無
2618 接頭詞,名詞接続,*,*,*,*,第
2619 接頭詞,名詞接続,*,*,*,*,等
2620 接頭詞,名詞接続,*,*,*,*,約
2621 接頭詞,名詞接続,*,*,*,*,自
2622 接頭詞,名詞接続,*,*,*,*,被
2623 接頭詞,名詞接続,*,*,*,*,要
2624 接頭詞,名詞接続,*,*,*,*,超
2625 接頭詞,名詞接続,*,*,*,*,長
2626 接頭詞,名詞接続,*,*,*,*,非
2627 接頭詞,名詞接続,*,*,*,*,高
2628 接頭詞,形容詞接続,*,*,*,*,*
2629 接頭詞,数接続,*,*,*,*,*
2630 接頭詞,数接続,*,*,*,*,何
2631 接頭詞,数接続,*,*,*,*,助数詞接続可能
2632 接頭詞,数接続,*,*,*,*,数
2633 記号,アルファベット,*,*,*,*,*
2634 記号,一般,*,*,*,*,*
2635 記号,句点,*,*,*,*,*
2636 記号,括弧閉,*,*,*,*,*
2637 記号,括弧開,*,*,*,*,*
2638 記号,読点,*,*,*,*,*
2639 連体詞,*,*,*,*,*,*
2640 連体詞,*,*,*,*,*,あの
2641 連体詞,*,*,*,*,*,ある
2642 連体詞,*,*,*,*,*,この
2643 連体詞,*,*,*,*,*,こんな
2644 連体詞,*,*,*,*,*,その
2645 連体詞,*,*,*,*,*,そんな
2646 連体詞,*,*,*,*,*,とある
2647 連体詞,*,*,*,*,*,どの
2648 連体詞,*,*,*,*,*,どんな
2649 連体詞,*,*,*,*,*,わが
2650 連体詞,*,*,*,*,*,同じ
2651 連体詞,*,*,*,*,*,我が
